<?php
if ( ! defined( 'ABSPATH' ) ) exit;
/**
 * Fired during plugin activation
 *
 * @link       http://myworks.design/software/wordpress/woocommerce/myworks-wc-qbo-sync
 * @since      1.0.0
 *
 * @package    MW_QBO_Desktop
 * @subpackage MW_QBO_Desktop/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    MW_QBO_Desktop
 * @subpackage MW_QBO_Desktop/includes
 * @author     My Works <support@myworks.design>
 */

class MW_QBO_Desktop_Sync_Qwc_Server_Lib extends MW_QBO_Desktop_Sync_Lib{
	private $qbd_timezone;
	
	public function __construct($dsn){
		if(!session_id()) {
			session_start();
		}
		
		parent::__construct();
		
		if($this->dsn && QuickBooks_Utilities::initialized($this->dsn)){
			QuickBooks_WebConnector_Queue_Singleton::initialize($this->dsn);
		}

		if (function_exists('date_default_timezone_set')){			
			$qbd_tz_setting = $this->get_qbd_timezone();
			//$qbd_tz_setting = 'America/New_York';
			date_default_timezone_set($qbd_tz_setting);
			$this->qbd_timezone = $qbd_tz_setting;
		}
		
		if(isset($_GET['debug'])){
			$this->debug();
		}
		
	}
	
	public function debug(){
		//echo $this->GetProductQbxml(75,'Inventory');
		//echo $this->GetProductQbxml(42,'NonInventory');
		//echo $this->GetSalesReceiptQbxml(69);
		//echo $this->GetSalesOrderQbxml(195);
		//$this->_p($this->get_order_base_currency_total_from_order_id(183));
		//$this->_p($this->get_wc_order_details_from_order(195,get_post(195)));
		//echo $this->GetInvoiceQbxml(178);
		//echo $this->GetCustomerQbxml(11);
		//echo $this->GetPaymentQbxml(4630);
		//echo $this->GetInventoryAdjustmentAddQbxml(76);
		//$this->_p($this->get_wc_variation_info(86));
		//echo $this->GetProductQbxml(86,'NonInventory',1);
		//echo $this->server_timezone;
		//echo $this->get_auto_inventory_pull_m_dt_from();
	}


	private function getonError(){
		$onError = 'continueOnError';//stopOnError
		return $onError;
	}

	private function get_qbxml_prefix($version='6.0'){
		$version = '13.0';
		$xml_encoding = $this->get_option('mw_wc_qbo_desk_xml_req_encoding');
		if($xml_encoding!='utf-8' && $xml_encoding!='ISO-8859-1'){
			$xml_encoding = 'utf-8';
		}
		//qbxml version="2.0"
		return '
			<?xml version="1.0" encoding="'.$xml_encoding.'"?>
			<?qbxml version="'.$version.'"?>
			<QBXML>
			<QBXMLMsgsRq onError="'.$this->getonError().'">
		';
		//continueOnError#stopOnError
	}

	private function get_qbxml_suffix(){
		return '
			</QBXMLMsgsRq>
			</QBXML>
		';
	}
	
	public function get_qbxml_locale(){
		$sl = trim($this->get_option('mw_wc_qbo_desk_xml_req_locale'));
		if($sl==''){$sl = 'US';}
		return $sl;
	}
	
	/*QBXML Functions*/
	public function GetInvoiceQbxml($order_id,$update=false){
		if($this->is_qwc_connected()){
			$order = get_post($order_id);
			$invoice_data = $this->get_wc_order_details_from_order($order_id,$order);
			//$this->add_test_log(print_r($invoice_data,true));
			//$this->_p($invoice_data);
			if(is_array($invoice_data) && count($invoice_data)){
				global $wpdb;
				$wc_cus_id = (int) $this->get_array_isset($invoice_data,'wc_cus_id',0);
				$qbo_cus_id = '';

				$wc_inv_id = (int) $this->get_array_isset($invoice_data,'wc_inv_id',0);
				$wc_inv_num = $this->get_array_isset($invoice_data,'wc_inv_num','');
				
				$_order_currency = $this->get_array_isset($invoice_data,'_order_currency','',true);
				
				$qbo_cus_id = '';
				if($this->is_plugin_active('woocommerce-aelia-currencyswitcher') && $this->option_checked('mw_wc_qbo_desk_wacs_satoc_cb')){				
					if($_order_currency!=''){
						$aelia_cur_cus_map = get_option('mw_wc_qbo_desk_wacs_satoc_map_cur_cus');
						if(is_array($aelia_cur_cus_map) && count($aelia_cur_cus_map)){
							if(isset($aelia_cur_cus_map[$_order_currency]) && trim($aelia_cur_cus_map[$_order_currency])!=''){
								$qbo_cus_id = trim($aelia_cur_cus_map[$_order_currency]);
							}
						}
					}					
				}
				
				if(empty($qbo_cus_id)){
					if(!$this->option_checked('mw_wc_qbo_desk_all_order_to_customer')){
						if($wc_cus_id>0){
							//$qbo_cus_id = $this->get_wc_data_pair_val('Customer',$wc_cus_id);
							if($this->option_checked('mw_wc_qbo_desk_customer_qbo_check_billing_company')){
								$customer_data = $this->get_wc_customer_info_from_order($order_id);
							}else{
								$customer_data = $this->get_wc_customer_info($wc_cus_id);
							}						
							//$this->_p($customer_data);
							$qbo_cus_id = $this->if_qbo_customer_exists($customer_data);
						}else{
							$customer_data = $this->get_wc_customer_info_from_order($order_id);
							$qbo_cus_id = $this->if_qbo_guest_exists($customer_data);
						}
					}else{
						if($wc_cus_id>0){
							$user_info = get_userdata($wc_cus_id);
							$io_cs = false;
							if(isset($user_info->roles) && is_array($user_info->roles)){
								$sc_roles_as_cus = $this->get_option('mw_wc_qbo_desk_wc_cust_role_sync_as_cus');
								if(!empty($sc_roles_as_cus)){
									$sc_roles_as_cus = explode(',',$sc_roles_as_cus);
									if(is_array($sc_roles_as_cus) && count($sc_roles_as_cus)){
										foreach($sc_roles_as_cus as $sr){
											if(in_array($sr,$user_info->roles)){
												$io_cs = true;
												break;
											}
										}
									}
								}
							}
							
							if($io_cs){
								if($this->option_checked('mw_wc_qbo_desk_customer_qbo_check_billing_company')){
									$customer_data = $this->get_wc_customer_info_from_order($order_id);
								}else{
									$customer_data = $this->get_wc_customer_info($wc_cus_id);
								}							
								$qbo_cus_id = $this->if_qbo_customer_exists($customer_data);
							}else{
								$qbo_cus_id = $this->get_option('mw_wc_qbo_desk_customer_to_sync_all_orders');
							}
							
						}else{
							$qbo_cus_id = $this->get_option('mw_wc_qbo_desk_customer_to_sync_all_orders');
						}
					}
				}				
				
				if(empty($qbo_cus_id)){
					$this->save_log(array('log_type'=>'Order','log_title'=>'Export Order Error #'.$order_id,'details'=>'QuickBooks Customer Not Found','status'=>0));
					return false;
				}

				if($qbo_cus_id!=''){
					$DocNumber = ($wc_inv_num!='')?$wc_inv_num:$wc_inv_id;
					$Invoice = new QuickBooks_QBXML_Object_Invoice();

					//$Invoice->setCustomerName();
					$Invoice->setCustomerListID($qbo_cus_id);
					$Invoice->setRefNumber($DocNumber);

					$wc_inv_date = $this->get_array_isset($invoice_data,'wc_inv_date','');
					$wc_inv_date = $this->format_date($wc_inv_date);
					if($wc_inv_date!=''){
						$Invoice->setTxnDate($wc_inv_date);
					}

					$wc_inv_due_date = $this->get_array_isset($invoice_data,'wc_inv_due_date','');
					$wc_inv_due_date = $this->format_date($wc_inv_due_date);
					if($wc_inv_due_date!=''){
						$Invoice->setDueDate($wc_inv_due_date);
					}
					
					
					$_payment_method = $this->get_array_isset($invoice_data,'_payment_method','',true);
					
					/*Count Total Amounts*/
					$_cart_discount = $this->get_array_isset($invoice_data,'_cart_discount',0);
					$_cart_discount_tax = $this->get_array_isset($invoice_data,'_cart_discount_tax',0);

					$_order_tax = $this->get_array_isset($invoice_data,'_order_tax',0);
					$_order_shipping_tax = (float) $this->get_array_isset($invoice_data,'_order_shipping_tax',0);
					$_order_total_tax = ($_order_tax+$_order_shipping_tax);

					$order_shipping_total = $this->get_array_isset($invoice_data,'order_shipping_total',0);
					
					if($this->wacs_base_cur_enabled()){
						$_cart_discount_base_currency = $this->get_array_isset($invoice_data,'_cart_discount_base_currency',0);
						$_cart_discount_tax_base_currency = $this->get_array_isset($invoice_data,'_cart_discount_tax_base_currency',0);
						
						$_order_tax_base_currency = $this->get_array_isset($invoice_data,'_order_tax_base_currency',0);
						$_order_shipping_tax_base_currency = $this->get_array_isset($invoice_data,'_order_shipping_tax_base_currency',0);
						$_order_total_tax_base_currency = ($_order_tax_base_currency+$_order_shipping_tax_base_currency);
						
						$order_shipping_total_base_currency = $this->get_array_isset($invoice_data,'_order_shipping_base_currency',0);
					}
					
					/*Qbd settings*/
					$qbo_is_sales_tax = true;
					$qbo_company_country = 'US';
					$qbo_is_shipping_allowed = false;

					/*Tax rates*/
					$qbo_tax_code = '';
					$apply_tax = false;
					$is_tax_applied = false;
					$is_inclusive = false;

					$qbo_tax_code_shipping = '';

					$tax_rate_id = 0;
					$tax_rate_id_2 = 0;

					$tax_details = (isset($invoice_data['tax_details']))?$invoice_data['tax_details']:array();
					
					//Tax Totals From tax Lines
					$calc_order_tax_totals_from_tax_lines = true;					
					if($calc_order_tax_totals_from_tax_lines){
						$_order_tax = 0;
						$_order_shipping_tax = 0;
						$_order_total_tax = 0;
						
						if($this->wacs_base_cur_enabled()){
							$_order_tax_base_currency = 0;
							$_order_shipping_tax_base_currency = 0;
							$_order_total_tax_base_currency = 0;
						}
						
						if(count($tax_details)){
							foreach($tax_details as $td){
								$_order_tax+=$td['tax_amount'];
								$_order_shipping_tax+=$td['shipping_tax_amount'];
								$_order_total_tax+=$td['tax_amount']+$td['shipping_tax_amount'];
								
								if($this->wacs_base_cur_enabled()){
									$_order_tax_base_currency+=$td['tax_amount_base_currency'];
									$_order_shipping_tax_base_currency+=$td['shipping_tax_amount_base_currency'];
									$_order_total_tax_base_currency+=$td['tax_amount_base_currency']+$td['shipping_tax_amount_base_currency'];
								}
							}
						}
					}
					$_order_total_tax = $this->qbd_limit_decimal_points($_order_total_tax);
					if($this->wacs_base_cur_enabled()){
						$_order_total_tax_base_currency = $this->qbd_limit_decimal_points($_order_total_tax_base_currency);
					}
					
					//TaxJar Settings
					$is_taxjar_active = false;
					$woocommerce_taxjar_integration_settings = get_option('woocommerce_taxjar-integration_settings');
					$wc_taxjar_enable_tax_calculation = 0;
					if(is_array($woocommerce_taxjar_integration_settings) && count($woocommerce_taxjar_integration_settings)){
						if(isset($woocommerce_taxjar_integration_settings['enabled']) && $woocommerce_taxjar_integration_settings['enabled']=='yes'){
							$wc_taxjar_enable_tax_calculation = 1;
						}
					}
					
					if($this->is_plugin_active('taxjar-simplified-taxes-for-woocommerce','taxjar-woocommerce') && $this->option_checked('mw_wc_qbo_desk_wc_taxjar_support') && $wc_taxjar_enable_tax_calculation=='1'){
						$is_taxjar_active = true;
						$qbo_is_sales_tax = false;
					}
					
					//Avatax Settings
					$is_avatax_active = false;
					$wc_avatax_enable_tax_calculation = get_option('wc_avatax_enable_tax_calculation');
					if($this->is_plugin_active('woocommerce-avatax') && $this->option_checked('mw_wc_qbo_desk_wc_avatax_support') && $wc_avatax_enable_tax_calculation=='yes'){
						$is_avatax_active = true;
						$qbo_is_sales_tax = false;
					}
					
					if($qbo_is_sales_tax){
						if(count($tax_details)){
							$tax_rate_id = $tax_details[0]['rate_id'];
						}

						if(count($tax_details)>1){
							if($tax_details[1]['tax_amount']>0){
								$tax_rate_id_2 = $tax_details[1]['rate_id'];
							}
						}

						/*
						if(count($tax_details)>1 && $qbo_is_shipping_allowed){
							foreach($tax_details as $td){
								if($td['tax_amount']==0 && $td['shipping_tax_amount']>0){
									$qbo_tax_code_shipping = $this->get_qbo_mapped_tax_code($td['rate_id'],0);
									break;
								}
							}
						}
						*/
						
						$qbo_tax_code = $this->get_qbo_mapped_tax_code($tax_rate_id,$tax_rate_id_2);
						if($qbo_tax_code!='' || $qbo_tax_code!='NON'){
							$apply_tax = true;
						}

						//$Tax_Code_Details = $this->mod_qbo_get_tx_dtls($qbo_tax_code);
						$is_qbo_dual_tax = false;

						/*
						if(count($Tax_Code_Details)){
							if($Tax_Code_Details['TaxGroup'] && count($Tax_Code_Details['TaxRateDetail'])>1){
								$is_qbo_dual_tax = true;
							}
						}

						$Tax_Rate_Ref = (isset($Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef']:'';
						$TaxPercent = $this->get_qbo_tax_rate_value_by_key($Tax_Rate_Ref);
						$Tax_Name = (isset($Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef_name']:'';

						$NetAmountTaxable = 0;

						if($is_qbo_dual_tax){
							$Tax_Rate_Ref_2 = (isset($Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef']:'';
							$TaxPercent_2 = $this->get_qbo_tax_rate_value_by_key($Tax_Rate_Ref_2);
							$Tax_Name_2 = (isset($Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef_name']:'';
							$NetAmountTaxable_2 = 0;
						}
						*/

						/*
						if($qbo_tax_code_shipping!=''){
							$Tax_Code_Details_Shipping = $this->mod_qbo_get_tx_dtls($qbo_tax_code_shipping);
							$Tax_Rate_Ref_Shipping = (isset($Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef']:'';
							$TaxPercent_Shipping = $this->get_qbo_tax_rate_value_by_key($Tax_Rate_Ref_Shipping);
							$Tax_Name_Shipping = (isset($Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef_name']:'';
							$NetAmountTaxable_Shipping = 0;
						}
						*/

						$_prices_include_tax = $this->get_array_isset($invoice_data,'_prices_include_tax','no',true);
						if($qbo_is_sales_tax){
							$tax_type = $this->get_tax_type($_prices_include_tax);
							$is_inclusive = $this->is_tax_inclusive($tax_type);
						}
					}


					$qbo_inv_items = (isset($invoice_data['qbo_inv_items']))?$invoice_data['qbo_inv_items']:array();
					if(is_array($qbo_inv_items) && count($qbo_inv_items)){
						foreach($qbo_inv_items as $qbo_item){
							$InvoiceLine = new QuickBooks_QBXML_Object_Invoice_InvoiceLine();
							//$InvoiceLine->setItemName($qbo_item['Description']);
							$InvoiceLine->setItemListID($qbo_item["ItemRef"]);
							if(isset($qbo_item["ClassRef"]) && $qbo_item["ClassRef"]!=''){
								$InvoiceLine->setClassListID($qbo_item["ClassRef"]);
							}
							
							$Description = $qbo_item['Description'];
							if($this->option_checked('mw_wc_qbo_desk_add_sku_af_lid')){
								$li_item_id = ($qbo_item["variation_id"]>0)?$qbo_item["variation_id"]:$qbo_item["product_id"];
								$li_sku = get_post_meta( $li_item_id, '_sku', true );
								if($li_sku!=''){
									$Description.=' ('.$li_sku.')';
								}
							}
							
							$UnitPrice = $qbo_item["UnitPrice"];
							if($this->wacs_base_cur_enabled()){
								$UnitPrice = $qbo_item["UnitPrice_base_currency"];
								$Description.= " ({$_order_currency} ".$qbo_item["UnitPrice"].")";
							}
							
							if(!$this->option_checked('mw_wc_qbo_desk_skip_os_lid')){
								$InvoiceLine->setDesc($Description);
							}
							
							$Qty = $qbo_item["Qty"];
							$Amount = $Qty*$UnitPrice;
							$InvoiceLine->setRate($UnitPrice);
							$InvoiceLine->setQuantity($Qty);
							$InvoiceLine->setAmount($Amount);

							/*
							SerialNumber
							LotNumber
							ServiceDate
							*/

							if($qbo_is_sales_tax){
								if($apply_tax && $qbo_item["Taxed"]){
									$is_tax_applied = true;
									/*$TaxCodeRef = ($qbo_company_country=='US')?'TAX':$qbo_tax_code;*/
									//$TaxCodeRef =$qbo_tax_code;
									$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_tax_rule_taxable');

									/*
									if($is_inclusive){
										$TaxInclusiveAmt = ($qbo_item['line_total']+$qbo_item['line_tax']);
									}
									*/
									if($TaxCodeRef!=''){
										$InvoiceLine->setSalesTaxCodeListID($TaxCodeRef);
									}
								}else{
									$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
									$InvoiceLine->setSalesTaxCodeListID($zero_rated_tax_code);
								}
							}							
							
							if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync') && $qbo_item["qbo_product_type"]=='Inventory'){
								$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
								if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
									$InvoiceLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
								}
							}

							$Invoice->addInvoiceLine($InvoiceLine);
						}
					}
					
					/*Add Invoice Coupons*/
					$used_coupons  = (isset($invoice_data['used_coupons']))?$invoice_data['used_coupons']:array();
					$qbo_is_discount_allowed = false;

					if(count($used_coupons)){
						foreach($used_coupons as $coupon){
							$coupon_name = $coupon['name'];
							$coupon_discount_amount = $coupon['discount_amount'];
							$coupon_discount_amount = -1 * abs($coupon_discount_amount);
							$coupon_discount_amount_tax = $coupon['discount_amount_tax'];
							
							if($this->wacs_base_cur_enabled()){
								$coupon_discount_amount_base_currency = $this->get_array_isset($coupon,'discount_amount_base_currency',0);
								$coupon_discount_amount_base_currency = -1 * abs($coupon_discount_amount_base_currency);
								
								$coupon_discount_amount_tax_base_currency = $coupon['discount_amount_tax_base_currency'];
							}

							$coupon_product_arr = $this->get_mapped_coupon_product($coupon_name);
							$DiscountLine = new QuickBooks_QBXML_Object_Invoice_InvoiceLine();
							$DiscountLine->setItemListID($coupon_product_arr["ItemRef"]);
							if(isset($coupon_product_arr["ClassRef"]) && $coupon_product_arr["ClassRef"]!=''){
								$DiscountLine->setClassListID($coupon_product_arr["ClassRef"]);
							}
							$Description = $coupon_product_arr['Description'];							
							
							if($this->wacs_base_cur_enabled()){
								$Description.= " ({$_order_currency} {$coupon_discount_amount})";
								$DiscountLine->setRate($coupon_discount_amount_base_currency);
								$DiscountLine->setAmount($coupon_discount_amount_base_currency);								
							}else{
								$DiscountLine->setRate($coupon_discount_amount);
								$DiscountLine->setAmount($coupon_discount_amount);
							}
							
							$DiscountLine->setQuantity(1);
							$DiscountLine->setDesc($Description);
							
							if($qbo_is_sales_tax){
								if($coupon_discount_amount_tax > 0 || $is_tax_applied){
									//$TaxCodeRef =$qbo_tax_code;
									$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_tax_rule_taxable');
									if($TaxCodeRef!=''){
										$DiscountLine->setSalesTaxCodeListID($TaxCodeRef);
									}
								}else{
									$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
									$DiscountLine->setSalesTaxCodeListID($zero_rated_tax_code);
								}								
							}
							
							if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
								$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
								if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
									//$DiscountLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
								}
							}
							
							$Invoice->addInvoiceLine($DiscountLine);
						}
					}
					
					/*Add Invoice Shipping*/
					$shipping_details  = (isset($invoice_data['shipping_details']))?$invoice_data['shipping_details']:array();

					$shipping_method = '';
					$shipping_method_name = '';
					$shipping_taxes = '';
					if(isset($shipping_details[0])){
						if($this->get_array_isset($shipping_details[0],'type','')=='shipping'){
							$shipping_method_id = $this->get_array_isset($shipping_details[0],'method_id','');
							if($shipping_method_id!=''){
								$shipping_method = $this->wc_get_sm_data_from_method_id_str($shipping_method_id);
							}
							$shipping_method = ($shipping_method=='')?'no_method_found':$shipping_method;
							$shipping_method_name =  $this->get_array_isset($shipping_details[0],'name','',true,30);
							$shipping_taxes = $this->get_array_isset($shipping_details[0],'taxes','');
						}
					}
					
					if(!$is_taxjar_active){
						//$order_shipping_total+=$_order_shipping_tax;
						if($this->wacs_base_cur_enabled()){
							//$order_shipping_total_base_currency+=$_order_shipping_tax_base_currency;
						}
					}					
					
					if($shipping_method!=''){
						if(!$qbo_is_shipping_allowed){
							$shipping_product_arr = $this->get_mapped_shipping_product($shipping_method);
							$ShippingLine = new QuickBooks_QBXML_Object_Invoice_InvoiceLine();
							$ShippingLine->setItemListID($shipping_product_arr["ItemRef"]);
							if(isset($shipping_product_arr["ClassRef"]) && $shipping_product_arr["ClassRef"]!=''){
								$ShippingLine->setClassListID($shipping_product_arr["ClassRef"]);
							}
							$shipping_description = ($shipping_method_name!='')?'Shipping ('.$shipping_method_name.')':'Shipping';							
							
							if($this->wacs_base_cur_enabled()){
								$shipping_description.= " ({$_order_currency} {$order_shipping_total})";
								$ShippingLine->setRate($order_shipping_total_base_currency);
								$ShippingLine->setAmount($order_shipping_total_base_currency);
							}else{
								$ShippingLine->setRate($order_shipping_total);								
								$ShippingLine->setAmount($order_shipping_total);
							}
							
							//$ShippingLine->setQuantity(1);
							$ShippingLine->setDesc($shipping_description);
							
							if($qbo_is_sales_tax){
								if($_order_shipping_tax>0){
									//$TaxCodeRef =$qbo_tax_code;
									$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_tax_rule_taxable');
									if(empty($TaxCodeRef)){
										$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_shipping_tax_rule_taxable');
									}
									
									if($TaxCodeRef!=''){
										$ShippingLine->setSalesTaxCodeListID($TaxCodeRef);
									}
								}else{
									$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
									$ShippingLine->setSalesTaxCodeListID($zero_rated_tax_code);
								}
							}
							
							if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
								$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
								if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
									//$ShippingLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
								}
							}

							$Invoice->addInvoiceLine($ShippingLine);

						}
					}
					
					
					//TaxJar Line
					if($is_taxjar_active && count($tax_details) && $_order_total_tax >0){
						$ExtLine = new QuickBooks_QBXML_Object_Invoice_InvoiceLine();
						$taxjar_item = $this->get_option('mw_wc_qbo_desk_wc_taxjar_map_qbo_product');
						if(empty($taxjar_item)){
							$taxjar_item = $this->get_option('mw_wc_qbo_desk_default_qbo_item');
						}
						
						$ExtLine->setItemListID($taxjar_item);
						$Description = 'TaxJar - QBD Line Item';
						
						if($this->wacs_base_cur_enabled()){
							$Description.= " ({$_order_currency} {$_order_total_tax})";
							//$ExtLine->setRate($_order_tax_base_currency);
							$ExtLine->setAmount($_order_total_tax_base_currency);
						}else{
							//$ExtLine->setRate($_order_tax);
							$ExtLine->setAmount($_order_total_tax);
						}
						
						//$ExtLine->setQuantity(1);
						$ExtLine->setDesc($Description);

						if($qbo_is_sales_tax){
							$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
							$ExtLine->setSalesTaxCodeListID($zero_rated_tax_code);
						}
						
						if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
							$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
							if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
								//$ExtLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
							}
						}

						$Invoice->addInvoiceLine($ExtLine);
					}
					
					//Avatax Line
					if($is_avatax_active && count($tax_details) && $_order_total_tax >0){
						$ExtLine = new QuickBooks_QBXML_Object_Invoice_InvoiceLine();
						$avatax_item = $this->get_option('mw_wc_qbo_desk_wc_avatax_map_qbo_product');
						if(empty($avatax_item)){
							$avatax_item = $this->get_option('mw_wc_qbo_desk_default_qbo_item');
						}
						
						$ExtLine->setItemListID($avatax_item);
						$Description = 'Avatax - QBD Line Item';				
						
						if($this->wacs_base_cur_enabled()){
							$Description.= " ({$_order_currency} {$_order_total_tax})";
							//$ExtLine->setRate($_order_tax_base_currency);
							$ExtLine->setAmount($_order_total_tax_base_currency);
						}else{
							//$ExtLine->setRate($_order_tax);
							$ExtLine->setAmount($_order_total_tax);
						}
						
						//$ExtLine->setQuantity(1);
						
						$ExtLine->setDesc($Description);

						if($qbo_is_sales_tax){
							$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
							$ExtLine->setSalesTaxCodeListID($zero_rated_tax_code);
						}
						
						if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
							$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
							if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
								//$ExtLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
							}
						}

						$Invoice->addInvoiceLine($ExtLine);
					}

					//
					if($is_tax_applied){
						$TaxCodeRef =$qbo_tax_code;
						if($TaxCodeRef!=''){
							$Invoice->setSalesTaxItemListID($TaxCodeRef);
						}
					}					
					
					//31-10-2017
					$is_as_addr_format = true;


					$billing_name = $this->get_array_isset($invoice_data,'_billing_first_name','',true).' '.$this->get_array_isset($invoice_data,'_billing_last_name','',true);
					$billing_name_fl = $billing_name;

					$country = $this->get_array_isset($invoice_data,'_billing_country','',true);
					$country = $this->get_country_name_from_code($country);
					//$country = '';
					
					$_billing_company = $this->get_array_isset($invoice_data,'_billing_company','',true);
					$_billing_address_1 = $this->get_array_isset($invoice_data,'_billing_address_1','',true);
					$_billing_address_2 = $this->get_array_isset($invoice_data,'_billing_address_2','',true);
					$_billing_city = $this->get_array_isset($invoice_data,'_billing_city','',true);
					$_billing_state = $this->get_array_isset($invoice_data,'_billing_state','',true);
					$_billing_postcode = $this->get_array_isset($invoice_data,'_billing_postcode','',true);
					
					$_billing_phone = $this->get_array_isset($invoice_data,'_billing_phone','',true);
					
					if(!$is_as_addr_format){
						if($_billing_company!=''){
							$Invoice->setBillAddress(
								$billing_name,$_billing_company,$_billing_address_1,$_billing_address_2,'',$_billing_city,$_billing_state,'',$_billing_postcode,
								$country
							);
						}else{
							$Invoice->setBillAddress(
								$billing_name,$_billing_address_1,$_billing_address_2,'','',$_billing_city,$_billing_state,'',$_billing_postcode,
								$country
							);
						}
					}else{
						$rfs_arr = array($this->get_array_isset($invoice_data,'_billing_first_name','',true),$this->get_array_isset($invoice_data,'_billing_last_name','',true),$_billing_company,$_billing_address_1,$_billing_address_2,$_billing_city,$_billing_state,$_billing_postcode,$_billing_phone,$country);
						$r_fa = $this->get_ord_baf_addrs($rfs_arr);
						$Invoice->setBillAddress(
							$this->get_array_isset($r_fa,0,'',true),
							$this->get_array_isset($r_fa,1,'',true),
							$this->get_array_isset($r_fa,2,'',true),
							$this->get_array_isset($r_fa,3,'',true),
							$this->get_array_isset($r_fa,4,'',true)
							
						);
					}

					if($this->get_array_isset($invoice_data,'_shipping_first_name','',true)!=''){
						$shipping_name = $this->get_array_isset($invoice_data,'_shipping_first_name','',true).' '.$this->get_array_isset($invoice_data,'_shipping_last_name','',true);

						$country = $this->get_array_isset($invoice_data,'_shipping_country','',true);
						$country = $this->get_country_name_from_code($country);
						
						$_shipping_company = $this->get_array_isset($invoice_data,'_shipping_company','',true);
						$_shipping_address_1 = $this->get_array_isset($invoice_data,'_shipping_address_1','',true);
						$_shipping_address_2 = $this->get_array_isset($invoice_data,'_shipping_address_2','',true);
						$_shipping_city = $this->get_array_isset($invoice_data,'_shipping_city','',true);
						$_shipping_state = $this->get_array_isset($invoice_data,'_shipping_state','',true);
						$_shipping_postcode = $this->get_array_isset($invoice_data,'_shipping_postcode','',true);
						
						if(!$is_as_addr_format){
							if($_shipping_company!=''){
								$Invoice->setShipAddress(
									$shipping_name,$_shipping_company,$_shipping_address_1,$_shipping_address_2,'',$_shipping_city,$_shipping_state,'',$_shipping_postcode,
									$country
								);
							}else{
								$Invoice->setShipAddress(
									$shipping_name,$_shipping_address_1,$_shipping_address_2,'','',$_shipping_city,$_shipping_state,'',$_shipping_postcode,
									$country
								);
							}
						}else{
							$rfs_arr = array($this->get_array_isset($invoice_data,'_shipping_first_name','',true),$this->get_array_isset($invoice_data,'_shipping_last_name','',true),$_shipping_company,$_shipping_address_1,$_shipping_address_2,$_shipping_city,$_shipping_state,$_shipping_postcode,$country);
							$r_fa = $this->get_ord_saf_addrs($rfs_arr);
							$Invoice->setShipAddress(
								$this->get_array_isset($r_fa,0,'',true),
								$this->get_array_isset($r_fa,1,'',true),
								$this->get_array_isset($r_fa,2,'',true),
								$this->get_array_isset($r_fa,3,'',true),
								$this->get_array_isset($r_fa,4,'',true)
								
							);
						}						
						
					}
					
					/*
					setShipAddress($addr1, $addr2 = '', $addr3 = '', $addr4 = '', $addr5 = '', $city = '', $state = '', $province = '', $postalcode = '', $country = '', $note = '')
					*/

					/*
					setBillAddress($addr1, $addr2 = '', $addr3 = '', $addr4 = '', $addr5 = '', $city = '', $state = '', $province = '', $postalcode = '', $country = '', $note = '')
					*/

					/*
					setShipMethodName
					setShipMethodListID
					setShipDate

					setPaymentMethodName
					setPaymentMethodListID
					
					setPONumber
					setSalesRepListID

					*/

					$customer_note = $this->get_array_isset($invoice_data,'customer_note','');
					if($this->option_checked('mw_wc_qbo_desk_invoice_memo')){
						$Invoice->setMemo($customer_note);
					}
					
					if($this->option_checked('mw_wc_qbo_desk_cname_into_memo')){
						$cname_memo = $billing_name_fl;
						$Invoice->setMemo($cname_memo);
					}
					
					//New - Extra Fields
					$mw_wc_qbo_desk_ord_push_rep_othername = $this->get_option('mw_wc_qbo_desk_ord_push_rep_othername');
					if($mw_wc_qbo_desk_ord_push_rep_othername!=''){
						$Invoice->setSalesRepListID($mw_wc_qbo_desk_ord_push_rep_othername);
					}
					
					if($this->is_plugin_active('woocommerce-gateway-purchase-order') && $this->option_checked('mw_wc_qbo_desk_wpopg_po_support')){
						//if($_payment_method == 'woocommerce_gateway_purchase_order'){}
						$_po_number = $this->get_array_isset($invoice_data,'_po_number','',true);
						if($_po_number!=''){
							$Invoice->setPONumber($_po_number);
						}else{
							$Invoice->setPONumber('Web');
						}
					}
					
					$mw_wc_qbo_desk_ord_push_entered_by = $this->get_option('mw_wc_qbo_desk_ord_push_entered_by');
					if($mw_wc_qbo_desk_ord_push_entered_by!=''){
						$Invoice->setOther($mw_wc_qbo_desk_ord_push_entered_by);
					}
					
					/*
					if($this->wacs_base_cur_enabled()){					
						$base_currency = get_woocommerce_currency();
						$pm_map_data = $this->get_mapped_payment_method_data($_payment_method,$base_currency);
					}else{
						$pm_map_data = $this->get_mapped_payment_method_data($_payment_method,$_order_currency);
					}
					*/
					
					//$this->_p($Invoice);
					
					$qbxml = $Invoice->asQBXML(QUICKBOOKS_ADD_INVOICE,null,$this->get_qbxml_locale());					
					$qbxml = $this->get_qbxml_prefix().$qbxml. $this->get_qbxml_suffix();					

					return $qbxml;

				}
			}
		}
	}
	
	public function format_xml($xml){
		$xml = trim($xml);		
		if(!empty($xml)){
			$dom = new DOMDocument;
			$dom->preserveWhiteSpace = FALSE;
			$dom->loadXML($xml);
			$dom->formatOutput = TRUE;
			$xml = $dom->saveXml();
		}
		return $xml;
	}
	
	/*SalesReceipt*/
	public function GetSalesReceiptQbxml($order_id,$update=false){
		if($this->is_qwc_connected()){
			$order = get_post($order_id);
			$invoice_data = $this->get_wc_order_details_from_order($order_id,$order);
			//$this->add_test_log(print_r($invoice_data,true));
			//$this->_p($invoice_data);
	
			if(is_array($invoice_data) && count($invoice_data)){
				global $wpdb;
				$wc_cus_id = (int) $this->get_array_isset($invoice_data,'wc_cus_id',0);
				$qbo_cus_id = '';

				$wc_inv_id = (int) $this->get_array_isset($invoice_data,'wc_inv_id',0);
				$wc_inv_num = $this->get_array_isset($invoice_data,'wc_inv_num','');
				
				$_order_currency = $this->get_array_isset($invoice_data,'_order_currency','',true);
				
				$qbo_cus_id = '';
				if($this->is_plugin_active('woocommerce-aelia-currencyswitcher') && $this->option_checked('mw_wc_qbo_desk_wacs_satoc_cb')){				
					if($_order_currency!=''){
						$aelia_cur_cus_map = get_option('mw_wc_qbo_desk_wacs_satoc_map_cur_cus');
						if(is_array($aelia_cur_cus_map) && count($aelia_cur_cus_map)){
							if(isset($aelia_cur_cus_map[$_order_currency]) && trim($aelia_cur_cus_map[$_order_currency])!=''){
								$qbo_cus_id = trim($aelia_cur_cus_map[$_order_currency]);
							}
						}
					}					
				}
				
				if(empty($qbo_cus_id)){
					if(!$this->option_checked('mw_wc_qbo_desk_all_order_to_customer')){
						if($wc_cus_id>0){
							//$qbo_cus_id = $this->get_wc_data_pair_val('Customer',$wc_cus_id);
							if($this->option_checked('mw_wc_qbo_desk_customer_qbo_check_billing_company')){
								$customer_data = $this->get_wc_customer_info_from_order($order_id);
							}else{
								$customer_data = $this->get_wc_customer_info($wc_cus_id);
							}
							
							$qbo_cus_id = $this->if_qbo_customer_exists($customer_data);
						}else{
							$customer_data = $this->get_wc_customer_info_from_order($order_id);
							$qbo_cus_id = $this->if_qbo_guest_exists($customer_data);
						}
					}else{
						if($wc_cus_id>0){
							$user_info = get_userdata($wc_cus_id);
							$io_cs = false;
							if(isset($user_info->roles) && is_array($user_info->roles)){
								$sc_roles_as_cus = $this->get_option('mw_wc_qbo_desk_wc_cust_role_sync_as_cus');
								if(!empty($sc_roles_as_cus)){
									$sc_roles_as_cus = explode(',',$sc_roles_as_cus);
									if(is_array($sc_roles_as_cus) && count($sc_roles_as_cus)){
										foreach($sc_roles_as_cus as $sr){
											if(in_array($sr,$user_info->roles)){
												$io_cs = true;
												break;
											}
										}
									}
								}
							}
							
							if($io_cs){
								if($this->option_checked('mw_wc_qbo_desk_customer_qbo_check_billing_company')){
									$customer_data = $this->get_wc_customer_info_from_order($order_id);
								}else{
									$customer_data = $this->get_wc_customer_info($wc_cus_id);
								}							
								$qbo_cus_id = $this->if_qbo_customer_exists($customer_data);
							}else{
								$qbo_cus_id = $this->get_option('mw_wc_qbo_desk_customer_to_sync_all_orders');
							}
							
						}else{
							$qbo_cus_id = $this->get_option('mw_wc_qbo_desk_customer_to_sync_all_orders');
						}
					}
				}				

				if(empty($qbo_cus_id)){
					$this->save_log(array('log_type'=>'Order','log_title'=>'Export Order Error #'.$order_id,'details'=>'QuickBooks Customer Not Found','status'=>0));
					return false;
				}

				if($qbo_cus_id!=''){
					$DocNumber = ($wc_inv_num!='')?$wc_inv_num:$wc_inv_id;
					$SalesReceipt = new QuickBooks_QBXML_Object_SalesReceipt();

					//$SalesReceipt->setCustomerName();
					$SalesReceipt->setCustomerListID($qbo_cus_id);
					$SalesReceipt->setRefNumber($DocNumber);

					$wc_inv_date = $this->get_array_isset($invoice_data,'wc_inv_date','');
					$wc_inv_date = $this->format_date($wc_inv_date);
					if($wc_inv_date!=''){
						$SalesReceipt->setTxnDate($wc_inv_date);
					}

					$wc_inv_due_date = $this->get_array_isset($invoice_data,'wc_inv_due_date','');
					$wc_inv_due_date = $this->format_date($wc_inv_due_date);
					if($wc_inv_due_date!=''){
						$SalesReceipt->setDueDate($wc_inv_due_date);
					}
					
					
					$_payment_method = $this->get_array_isset($invoice_data,'_payment_method','',true);
					
					/*Count Total Amounts*/
					$_cart_discount = $this->get_array_isset($invoice_data,'_cart_discount',0);
					$_cart_discount_tax = $this->get_array_isset($invoice_data,'_cart_discount_tax',0);

					$_order_tax = $this->get_array_isset($invoice_data,'_order_tax',0);
					$_order_shipping_tax = (float) $this->get_array_isset($invoice_data,'_order_shipping_tax',0);
					$_order_total_tax = ($_order_tax+$_order_shipping_tax);
					
					$order_shipping_total = $this->get_array_isset($invoice_data,'order_shipping_total',0);

					/*Qbd settings*/
					$qbo_is_sales_tax = true;
					$qbo_company_country = 'US';
					$qbo_is_shipping_allowed = false;

					/*Tax rates*/
					$qbo_tax_code = '';
					$apply_tax = false;
					$is_tax_applied = false;
					$is_inclusive = false;

					$qbo_tax_code_shipping = '';

					$tax_rate_id = 0;
					$tax_rate_id_2 = 0;

					$tax_details = (isset($invoice_data['tax_details']))?$invoice_data['tax_details']:array();
					
					//Tax Totals From tax Lines
					$calc_order_tax_totals_from_tax_lines = true;					
					if($calc_order_tax_totals_from_tax_lines){
						$_order_tax = 0;
						$_order_shipping_tax = 0;
						$_order_total_tax = 0;
						if(count($tax_details)){
							foreach($tax_details as $td){
								$_order_tax+=$td['tax_amount'];
								$_order_shipping_tax+=$td['shipping_tax_amount'];
								$_order_total_tax+=$td['tax_amount']+$td['shipping_tax_amount'];
							}
						}
					}
					
					$_order_total_tax = $this->qbd_limit_decimal_points($_order_total_tax);
					
					//TaxJar Settings
					$is_taxjar_active = false;
					$woocommerce_taxjar_integration_settings = get_option('woocommerce_taxjar-integration_settings');
					$wc_taxjar_enable_tax_calculation = 0;
					if(is_array($woocommerce_taxjar_integration_settings) && count($woocommerce_taxjar_integration_settings)){
						if(isset($woocommerce_taxjar_integration_settings['enabled']) && $woocommerce_taxjar_integration_settings['enabled']=='yes'){
							$wc_taxjar_enable_tax_calculation = 1;
						}
					}
					
					if($this->is_plugin_active('taxjar-simplified-taxes-for-woocommerce','taxjar-woocommerce') && $this->option_checked('mw_wc_qbo_desk_wc_taxjar_support') && $wc_taxjar_enable_tax_calculation=='1'){
						$is_taxjar_active = true;
						$qbo_is_sales_tax = false;
					}
					
					//Avatax Settings
					$is_avatax_active = false;
					$wc_avatax_enable_tax_calculation = get_option('wc_avatax_enable_tax_calculation');
					if($this->is_plugin_active('woocommerce-avatax') && $this->option_checked('mw_wc_qbo_desk_wc_avatax_support') && $wc_avatax_enable_tax_calculation=='yes'){
						$is_avatax_active = true;
						$qbo_is_sales_tax = false;
					}

					if($qbo_is_sales_tax){
						if(count($tax_details)){
							$tax_rate_id = $tax_details[0]['rate_id'];
						}

						if(count($tax_details)>1){
							if($tax_details[1]['tax_amount']>0){
								$tax_rate_id_2 = $tax_details[1]['rate_id'];
							}
						}

						/*
						if(count($tax_details)>1 && $qbo_is_shipping_allowed){
							foreach($tax_details as $td){
								if($td['tax_amount']==0 && $td['shipping_tax_amount']>0){
									$qbo_tax_code_shipping = $this->get_qbo_mapped_tax_code($td['rate_id'],0);
									break;
								}
							}
						}
						*/

						$qbo_tax_code = $this->get_qbo_mapped_tax_code($tax_rate_id,$tax_rate_id_2);
						if($qbo_tax_code!='' || $qbo_tax_code!='NON'){
							$apply_tax = true;
						}

						//$Tax_Code_Details = $this->mod_qbo_get_tx_dtls($qbo_tax_code);
						$is_qbo_dual_tax = false;

						/*
						if(count($Tax_Code_Details)){
							if($Tax_Code_Details['TaxGroup'] && count($Tax_Code_Details['TaxRateDetail'])>1){
								$is_qbo_dual_tax = true;
							}
						}

						$Tax_Rate_Ref = (isset($Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef']:'';
						$TaxPercent = $this->get_qbo_tax_rate_value_by_key($Tax_Rate_Ref);
						$Tax_Name = (isset($Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef_name']:'';

						$NetAmountTaxable = 0;

						if($is_qbo_dual_tax){
							$Tax_Rate_Ref_2 = (isset($Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef']:'';
							$TaxPercent_2 = $this->get_qbo_tax_rate_value_by_key($Tax_Rate_Ref_2);
							$Tax_Name_2 = (isset($Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef_name']:'';
							$NetAmountTaxable_2 = 0;
						}
						*/

						/*
						if($qbo_tax_code_shipping!=''){
							$Tax_Code_Details_Shipping = $this->mod_qbo_get_tx_dtls($qbo_tax_code_shipping);
							$Tax_Rate_Ref_Shipping = (isset($Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef']:'';
							$TaxPercent_Shipping = $this->get_qbo_tax_rate_value_by_key($Tax_Rate_Ref_Shipping);
							$Tax_Name_Shipping = (isset($Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef_name']:'';
							$NetAmountTaxable_Shipping = 0;
						}
						*/

						$_prices_include_tax = $this->get_array_isset($invoice_data,'_prices_include_tax','no',true);
						if($qbo_is_sales_tax){
							$tax_type = $this->get_tax_type($_prices_include_tax);
							$is_inclusive = $this->is_tax_inclusive($tax_type);
						}
					}


					$qbo_inv_items = (isset($invoice_data['qbo_inv_items']))?$invoice_data['qbo_inv_items']:array();
					if(is_array($qbo_inv_items) && count($qbo_inv_items)){
						foreach($qbo_inv_items as $qbo_item){
							$SalesReceiptLine = new QuickBooks_QBXML_Object_SalesReceipt_SalesReceiptLine();
							//$SalesReceiptLine->setItemName($qbo_item['Description']);
							$SalesReceiptLine->setItemListID($qbo_item["ItemRef"]);
							if(isset($qbo_item["ClassRef"]) && $qbo_item["ClassRef"]!=''){
								//$SalesReceiptLine->setClassListID($qbo_item["ClassRef"]);
							}
							
							$Description = $qbo_item['Description'];
							if($this->option_checked('mw_wc_qbo_desk_add_sku_af_lid')){
								$li_item_id = ($qbo_item["variation_id"]>0)?$qbo_item["variation_id"]:$qbo_item["product_id"];
								$li_sku = get_post_meta( $li_item_id, '_sku', true );
								if($li_sku!=''){
									$Description.=' ('.$li_sku.')';
								}
							}
							
							if(!$this->option_checked('mw_wc_qbo_desk_skip_os_lid')){
								$SalesReceiptLine->setDesc($Description);
							}							
							
							$UnitPrice = $qbo_item["UnitPrice"];
							$Qty = $qbo_item["Qty"];
							$Amount = $Qty*$UnitPrice;
							$SalesReceiptLine->setRate($UnitPrice);
							$SalesReceiptLine->setQuantity($Qty);
							$SalesReceiptLine->setAmount($Amount);

							/*
							SerialNumber
							LotNumber
							ServiceDate
							*/

							if($qbo_is_sales_tax){
								if($apply_tax && $qbo_item["Taxed"]){
									$is_tax_applied = true;
									/*$TaxCodeRef = ($qbo_company_country=='US')?'TAX':$qbo_tax_code;*/
									//$TaxCodeRef =$qbo_tax_code;
									$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_tax_rule_taxable');

									/*
									if($is_inclusive){
										$TaxInclusiveAmt = ($qbo_item['line_total']+$qbo_item['line_tax']);
									}
									*/
									if($TaxCodeRef!=''){
										$SalesReceiptLine->setSalesTaxCodeListID($TaxCodeRef);
									}
								}else{
									$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
									$SalesReceiptLine->setSalesTaxCodeListID($zero_rated_tax_code);
								}
							}
							
							if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync') && $qbo_item["qbo_product_type"]=='Inventory'){
								$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
								if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
									$SalesReceiptLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
								}
							}

							$SalesReceipt->addSalesReceiptLine($SalesReceiptLine);
						}
					}
					
					/*Add SalesReceipt Coupons*/
					$used_coupons  = (isset($invoice_data['used_coupons']))?$invoice_data['used_coupons']:array();
					$qbo_is_discount_allowed = false;

					if(count($used_coupons)){
						foreach($used_coupons as $coupon){
							$coupon_name = $coupon['name'];
							$coupon_discount_amount = $coupon['discount_amount'];
							$coupon_discount_amount = -1 * abs($coupon_discount_amount);
							$coupon_discount_amount_tax = $coupon['discount_amount_tax'];

							$coupon_product_arr = $this->get_mapped_coupon_product($coupon_name);
							$DiscountLine = new QuickBooks_QBXML_Object_SalesReceipt_SalesReceiptLine();
							$DiscountLine->setItemListID($coupon_product_arr["ItemRef"]);
							if(isset($coupon_product_arr["ClassRef"]) && $coupon_product_arr["ClassRef"]!=''){
								//$DiscountLine->setClassListID($coupon_product_arr["ClassRef"]);
							}
							$DiscountLine->setDesc($coupon_product_arr['Description']);
							$DiscountLine->setRate($coupon_discount_amount);
							//$DiscountLine->setQuantity(1);
							$DiscountLine->setAmount($coupon_discount_amount);

							if($qbo_is_sales_tax){
								if($coupon_discount_amount_tax > 0 || $is_tax_applied){
									//$TaxCodeRef =$qbo_tax_code;
									$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_tax_rule_taxable');
									if($TaxCodeRef!=''){
										$DiscountLine->setSalesTaxCodeListID($TaxCodeRef);
									}
								}else{
									$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
									$DiscountLine->setSalesTaxCodeListID($zero_rated_tax_code);
								}								
							}
							
							if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
								$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
								if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
									//$DiscountLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
								}
							}

							$SalesReceipt->addSalesReceiptLine($DiscountLine);
						}
					}

					/*Add SalesReceipt Shipping*/
					$shipping_details  = (isset($invoice_data['shipping_details']))?$invoice_data['shipping_details']:array();

					$shipping_method = '';
					$shipping_method_name = '';
					$shipping_taxes = '';
					if(isset($shipping_details[0])){
						if($this->get_array_isset($shipping_details[0],'type','')=='shipping'){
							$shipping_method_id = $this->get_array_isset($shipping_details[0],'method_id','');
							if($shipping_method_id!=''){
								$shipping_method = $this->wc_get_sm_data_from_method_id_str($shipping_method_id);
							}
							$shipping_method = ($shipping_method=='')?'no_method_found':$shipping_method;
							$shipping_method_name =  $this->get_array_isset($shipping_details[0],'name','',true,30);
							$shipping_taxes = $this->get_array_isset($shipping_details[0],'taxes','');
						}
					}
					
					if(!$is_taxjar_active){
						//$order_shipping_total+=$_order_shipping_tax;
					}
					
					if($shipping_method!=''){
						if(!$qbo_is_shipping_allowed){
							$shipping_product_arr = $this->get_mapped_shipping_product($shipping_method);
							$ShippingLine = new QuickBooks_QBXML_Object_SalesReceipt_SalesReceiptLine();
							$ShippingLine->setItemListID($shipping_product_arr["ItemRef"]);
							if(isset($shipping_product_arr["ClassRef"]) && $shipping_product_arr["ClassRef"]!=''){
								//$ShippingLine->setClassListID($shipping_product_arr["ClassRef"]);
							}
							$shipping_description = ($shipping_method_name!='')?'Shipping ('.$shipping_method_name.')':'Shipping';
							$ShippingLine->setDesc($shipping_description);

							$ShippingLine->setRate($order_shipping_total);
							//$ShippingLine->setQuantity(1);
							$ShippingLine->setAmount($order_shipping_total);
							
							if($qbo_is_sales_tax){
								if($_order_shipping_tax>0){
									//$TaxCodeRef =$qbo_tax_code;
									$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_tax_rule_taxable');
									if(empty($TaxCodeRef)){
										$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_shipping_tax_rule_taxable');
									}
									
									if($TaxCodeRef!=''){
										$ShippingLine->setSalesTaxCodeListID($TaxCodeRef);
									}
								}else{
									$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
									$ShippingLine->setSalesTaxCodeListID($zero_rated_tax_code);
								}
							}
							
							if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
								$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
								if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
									//$ShippingLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
								}
							}

							$SalesReceipt->addSalesReceiptLine($ShippingLine);

						}
					}
					
					//TaxJar Line
					if($is_taxjar_active && count($tax_details) && $_order_total_tax >0){
						$ExtLine = new QuickBooks_QBXML_Object_Invoice_InvoiceLine();
						$taxjar_item = $this->get_option('mw_wc_qbo_desk_wc_taxjar_map_qbo_product');
						if(empty($taxjar_item)){
							$taxjar_item = $this->get_option('mw_wc_qbo_desk_default_qbo_item');
						}
						
						$ExtLine->setItemListID($taxjar_item);
						$ExtLine->setDesc('TaxJar - QBD Line Item');
						//$ExtLine->setRate($_order_tax);
						//$ExtLine->setQuantity(1);
						$ExtLine->setAmount($_order_total_tax);

						if($qbo_is_sales_tax){
							$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
							$ExtLine->setSalesTaxCodeListID($zero_rated_tax_code);
						}
						
						if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
							$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
							if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
								//$ExtLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
							}
						}
						
						$SalesReceipt->addSalesReceiptLine($ExtLine);
					}
					
					//Avatax Line
					if($is_avatax_active && count($tax_details) && $_order_total_tax >0){
						$ExtLine = new QuickBooks_QBXML_Object_Invoice_InvoiceLine();
						$avatax_item = $this->get_option('mw_wc_qbo_desk_wc_avatax_map_qbo_product');
						if(empty($avatax_item)){
							$avatax_item = $this->get_option('mw_wc_qbo_desk_default_qbo_item');
						}
						
						$ExtLine->setItemListID($avatax_item);
						$ExtLine->setDesc('Avatax - QBD Line Item');
						//$ExtLine->setRate($_order_tax);
						//$ExtLine->setQuantity(1);
						$ExtLine->setAmount($_order_total_tax);

						if($qbo_is_sales_tax){
							$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
							$ExtLine->setSalesTaxCodeListID($zero_rated_tax_code);
						}
						
						if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
							$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
							if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
								//$ExtLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
							}
						}

						$SalesReceipt->addInvoiceLine($ExtLine);
					}
					
					//
					if($is_tax_applied){
						$TaxCodeRef =$qbo_tax_code;
						if($TaxCodeRef!=''){
							//$SalesReceipt->setSalesTaxItemListID($TaxCodeRef);
							$SalesReceipt->set('ItemSalesTaxRef ListID', $TaxCodeRef);
						}
					}
					
					//31-10-2017
					$is_as_addr_format = true;
					
					$billing_name = $this->get_array_isset($invoice_data,'_billing_first_name','',true).' '.$this->get_array_isset($invoice_data,'_billing_last_name','',true);
					
					$billing_name_fl = $billing_name;
					
					$country = $this->get_array_isset($invoice_data,'_billing_country','',true);
					$country = $this->get_country_name_from_code($country);
					//$country = '';
					
					
					$_billing_company = $this->get_array_isset($invoice_data,'_billing_company','',true);
					$_billing_address_1 = $this->get_array_isset($invoice_data,'_billing_address_1','',true);
					$_billing_address_2 = $this->get_array_isset($invoice_data,'_billing_address_2','',true);
					$_billing_city = $this->get_array_isset($invoice_data,'_billing_city','',true);
					$_billing_state = $this->get_array_isset($invoice_data,'_billing_state','',true);
					$_billing_postcode = $this->get_array_isset($invoice_data,'_billing_postcode','',true);
					
					$_billing_phone = $this->get_array_isset($invoice_data,'_billing_phone','',true);					
					
					if(!$is_as_addr_format){
						if($_billing_company!=''){
							$SalesReceipt->setBillAddress(
								$billing_name,$_billing_company,$_billing_address_1,$_billing_address_2,'',$_billing_city,$_billing_state,'',$_billing_postcode,
								$country
							);
							
						}else{
							$SalesReceipt->setBillAddress(
								$billing_name,$_billing_address_1,$_billing_address_2,'','',$_billing_city,$_billing_state,'',$_billing_postcode,
								$country
							);
						}
					}else{
						$rfs_arr = array($this->get_array_isset($invoice_data,'_billing_first_name','',true),$this->get_array_isset($invoice_data,'_billing_last_name','',true),$_billing_company,$_billing_address_1,$_billing_address_2,$_billing_city,$_billing_state,$_billing_postcode,$_billing_phone,$country);
						$r_fa = $this->get_ord_baf_addrs($rfs_arr);
						$SalesReceipt->setBillAddress(
							$this->get_array_isset($r_fa,0,'',true),
							$this->get_array_isset($r_fa,1,'',true),
							$this->get_array_isset($r_fa,2,'',true),
							$this->get_array_isset($r_fa,3,'',true),
							$this->get_array_isset($r_fa,4,'',true)
							
						);
					}					
					

					if($this->get_array_isset($invoice_data,'_shipping_first_name','',true)!=''){
						$shipping_name = $this->get_array_isset($invoice_data,'_shipping_first_name','',true).' '.$this->get_array_isset($invoice_data,'_shipping_last_name','',true);

						$country = $this->get_array_isset($invoice_data,'_shipping_country','',true);
						$country = $this->get_country_name_from_code($country);
						//$country = '';
						
						$_shipping_company = $this->get_array_isset($invoice_data,'_shipping_company','',true);
						$_shipping_address_1 = $this->get_array_isset($invoice_data,'_shipping_address_1','',true);
						$_shipping_address_2 = $this->get_array_isset($invoice_data,'_shipping_address_2','',true);
						$_shipping_city = $this->get_array_isset($invoice_data,'_shipping_city','',true);
						$_shipping_state = $this->get_array_isset($invoice_data,'_shipping_state','',true);
						$_shipping_postcode = $this->get_array_isset($invoice_data,'_shipping_postcode','',true);
						
						if(!$is_as_addr_format){
							if($_shipping_company!=''){
								$SalesReceipt->setShipAddress(
									$shipping_name,$_shipping_company,$_shipping_address_1,$_shipping_address_2,'',$_shipping_city,$_shipping_state,'',$_shipping_postcode,
									$country
								);
							}else{
								$SalesReceipt->setShipAddress(
									$shipping_name,$_shipping_address_1,$_shipping_address_2,'','',$_shipping_city,$_shipping_state,'',$_shipping_postcode,
									$country
								);
							}
						}else{
							$rfs_arr = array($this->get_array_isset($invoice_data,'_shipping_first_name','',true),$this->get_array_isset($invoice_data,'_shipping_last_name','',true),$_shipping_company,$_shipping_address_1,$_shipping_address_2,$_shipping_city,$_shipping_state,$_shipping_postcode,$country);
							$r_fa = $this->get_ord_saf_addrs($rfs_arr);
							$SalesReceipt->setShipAddress(
								$this->get_array_isset($r_fa,0,'',true),
								$this->get_array_isset($r_fa,1,'',true),
								$this->get_array_isset($r_fa,2,'',true),
								$this->get_array_isset($r_fa,3,'',true),
								$this->get_array_isset($r_fa,4,'',true)
								
							);
						}
						
					}
					
					/*
					setShipAddress($addr1, $addr2 = '', $addr3 = '', $addr4 = '', $addr5 = '', $city = '', $state = '', $province = '', $postalcode = '', $country = '', $note = '')
					*/

					/*
					setBillAddress($addr1, $addr2 = '', $addr3 = '', $addr4 = '', $addr5 = '', $city = '', $state = '', $province = '', $postalcode = '', $country = '', $note = '')
					*/

					/*
					setShipMethodName
					setShipMethodListID
					setShipDate

					setPaymentMethodName
					setPaymentMethodListID

					*/

					$customer_note = $this->get_array_isset($invoice_data,'customer_note','');
					if($this->option_checked('mw_wc_qbo_desk_invoice_memo')){
						$SalesReceipt->setMemo($customer_note);
					}

					if($this->option_checked('mw_wc_qbo_desk_cname_into_memo')){
						$cname_memo = $billing_name_fl;
						$SalesReceipt->setMemo($cname_memo);
					}
					
					//New - Extra Fields
					$mw_wc_qbo_desk_ord_push_rep_othername = $this->get_option('mw_wc_qbo_desk_ord_push_rep_othername');
					if($mw_wc_qbo_desk_ord_push_rep_othername!=''){
						$SalesReceipt->setSalesRepListID($mw_wc_qbo_desk_ord_push_rep_othername);
					}
					
					if($this->is_plugin_active('woocommerce-gateway-purchase-order') && $this->option_checked('mw_wc_qbo_desk_wpopg_po_support')){
						//if($_payment_method == 'woocommerce_gateway_purchase_order'){}
						$_po_number = $this->get_array_isset($invoice_data,'_po_number','',true);
						if($_po_number!=''){
							$SalesReceipt->setPONumber($_po_number);
						}else{
							$SalesReceipt->setPONumber('Web');
						}
					}
									
					$mw_wc_qbo_desk_ord_push_entered_by = $this->get_option('mw_wc_qbo_desk_ord_push_entered_by');
					if($mw_wc_qbo_desk_ord_push_entered_by!=''){
						$SalesReceipt->setOther($mw_wc_qbo_desk_ord_push_entered_by);
					}
					
					$qbxml = $SalesReceipt->asQBXML(QUICKBOOKS_ADD_SALESRECEIPT,null,$this->get_qbxml_locale());					
					$qbxml = $this->get_qbxml_prefix().$qbxml. $this->get_qbxml_suffix();					

					return $qbxml;

				}
			}
		}
	}
	
	/*SalesOrder QBXML*/
	public function GetSalesOrderQbxml($order_id,$update=false){
		if($this->is_qwc_connected()){
			$order = get_post($order_id);
			$invoice_data = $this->get_wc_order_details_from_order($order_id,$order);
			//$this->_p($invoice_data);
			if(is_array($invoice_data) && count($invoice_data)){
				global $wpdb;
				$wc_cus_id = (int) $this->get_array_isset($invoice_data,'wc_cus_id',0);
				$qbo_cus_id = '';
				
				$wc_inv_id = (int) $this->get_array_isset($invoice_data,'wc_inv_id',0);
				$wc_inv_num = $this->get_array_isset($invoice_data,'wc_inv_num','');
				
				$_order_currency = $this->get_array_isset($invoice_data,'_order_currency','',true);
				
				$qbo_cus_id = '';
				if($this->is_plugin_active('woocommerce-aelia-currencyswitcher') && $this->option_checked('mw_wc_qbo_desk_wacs_satoc_cb')){				
					if($_order_currency!=''){
						$aelia_cur_cus_map = get_option('mw_wc_qbo_desk_wacs_satoc_map_cur_cus');
						if(is_array($aelia_cur_cus_map) && count($aelia_cur_cus_map)){
							if(isset($aelia_cur_cus_map[$_order_currency]) && trim($aelia_cur_cus_map[$_order_currency])!=''){
								$qbo_cus_id = trim($aelia_cur_cus_map[$_order_currency]);
							}
						}
					}					
				}
				
				if(empty($qbo_cus_id)){
					if(!$this->option_checked('mw_wc_qbo_desk_all_order_to_customer')){
						if($wc_cus_id>0){
							//$qbo_cus_id = $this->get_wc_data_pair_val('Customer',$wc_cus_id);
							if($this->option_checked('mw_wc_qbo_desk_customer_qbo_check_billing_company')){
								$customer_data = $this->get_wc_customer_info_from_order($order_id);
							}else{
								$customer_data = $this->get_wc_customer_info($wc_cus_id);
							}						
							//$this->_p($customer_data);
							$qbo_cus_id = $this->if_qbo_customer_exists($customer_data);
						}else{
							$customer_data = $this->get_wc_customer_info_from_order($order_id);
							$qbo_cus_id = $this->if_qbo_guest_exists($customer_data);
						}
					}else{
						if($wc_cus_id>0){
							$user_info = get_userdata($wc_cus_id);
							$io_cs = false;
							if(isset($user_info->roles) && is_array($user_info->roles)){
								$sc_roles_as_cus = $this->get_option('mw_wc_qbo_desk_wc_cust_role_sync_as_cus');
								if(!empty($sc_roles_as_cus)){
									$sc_roles_as_cus = explode(',',$sc_roles_as_cus);
									if(is_array($sc_roles_as_cus) && count($sc_roles_as_cus)){
										foreach($sc_roles_as_cus as $sr){
											if(in_array($sr,$user_info->roles)){
												$io_cs = true;
												break;
											}
										}
									}
								}
							}
							
							if($io_cs){
								if($this->option_checked('mw_wc_qbo_desk_customer_qbo_check_billing_company')){
									$customer_data = $this->get_wc_customer_info_from_order($order_id);
								}else{
									$customer_data = $this->get_wc_customer_info($wc_cus_id);
								}							
								$qbo_cus_id = $this->if_qbo_customer_exists($customer_data);
							}else{
								$qbo_cus_id = $this->get_option('mw_wc_qbo_desk_customer_to_sync_all_orders');
							}
							
						}else{
							$qbo_cus_id = $this->get_option('mw_wc_qbo_desk_customer_to_sync_all_orders');
						}
					}
				}
				
				if(empty($qbo_cus_id)){
					$this->save_log(array('log_type'=>'Order','log_title'=>'Export Order Error #'.$order_id,'details'=>'QuickBooks Customer Not Found','status'=>0));
					return false;
				}
				
				if($qbo_cus_id!=''){
					$DocNumber = ($wc_inv_num!='')?$wc_inv_num:$wc_inv_id;
					$SalesOrder = new QuickBooks_QBXML_Object_SalesOrder();
					
					//$SalesOrder->setCustomerName();
					$SalesOrder->setCustomerListID($qbo_cus_id);
					$SalesOrder->setRefNumber($DocNumber);
					
					$wc_inv_date = $this->get_array_isset($invoice_data,'wc_inv_date','');
					$wc_inv_date = $this->format_date($wc_inv_date);
					if($wc_inv_date!=''){
						$SalesOrder->setTxnDate($wc_inv_date);
					}
					
					$wc_inv_due_date = $this->get_array_isset($invoice_data,'wc_inv_due_date','');
					$wc_inv_due_date = $this->format_date($wc_inv_due_date);
					if($wc_inv_due_date!=''){
						$SalesOrder->setDueDate($wc_inv_due_date);
					}
					
					
					$_payment_method = $this->get_array_isset($invoice_data,'_payment_method','',true);
					
					/*Count Total Amounts*/
					$_cart_discount = $this->get_array_isset($invoice_data,'_cart_discount',0);
					$_cart_discount_tax = $this->get_array_isset($invoice_data,'_cart_discount_tax',0);

					$_order_tax = $this->get_array_isset($invoice_data,'_order_tax',0);
					$_order_shipping_tax = (float) $this->get_array_isset($invoice_data,'_order_shipping_tax',0);
					$_order_total_tax = ($_order_tax+$_order_shipping_tax);

					$order_shipping_total = $this->get_array_isset($invoice_data,'order_shipping_total',0);

					/*Qbd settings*/
					$qbo_is_sales_tax = true;
					$qbo_company_country = 'US';
					$qbo_is_shipping_allowed = false;

					/*Tax rates*/
					$qbo_tax_code = '';
					$apply_tax = false;
					$is_tax_applied = false;
					$is_inclusive = false;

					$qbo_tax_code_shipping = '';

					$tax_rate_id = 0;
					$tax_rate_id_2 = 0;

					$tax_details = (isset($invoice_data['tax_details']))?$invoice_data['tax_details']:array();
					
					//Tax Totals From tax Lines
					$calc_order_tax_totals_from_tax_lines = true;					
					if($calc_order_tax_totals_from_tax_lines){
						$_order_tax = 0;
						$_order_shipping_tax = 0;
						$_order_total_tax = 0;
						
						if(count($tax_details)){
							foreach($tax_details as $td){
								$_order_tax+=$td['tax_amount'];
								$_order_shipping_tax+=$td['shipping_tax_amount'];
								$_order_total_tax+=$td['tax_amount']+$td['shipping_tax_amount'];
							}
						}
					}
					$_order_total_tax = $this->qbd_limit_decimal_points($_order_total_tax);
					
					//TaxJar Settings
					$is_taxjar_active = false;
					$woocommerce_taxjar_integration_settings = get_option('woocommerce_taxjar-integration_settings');
					$wc_taxjar_enable_tax_calculation = 0;
					if(is_array($woocommerce_taxjar_integration_settings) && count($woocommerce_taxjar_integration_settings)){
						if(isset($woocommerce_taxjar_integration_settings['enabled']) && $woocommerce_taxjar_integration_settings['enabled']=='yes'){
							$wc_taxjar_enable_tax_calculation = 1;
						}
					}
					
					if($this->is_plugin_active('taxjar-simplified-taxes-for-woocommerce','taxjar-woocommerce') && $this->option_checked('mw_wc_qbo_desk_wc_taxjar_support') && $wc_taxjar_enable_tax_calculation=='1'){
						$is_taxjar_active = true;
						$qbo_is_sales_tax = false;
					}
					
					//Avatax Settings
					$is_avatax_active = false;
					$wc_avatax_enable_tax_calculation = get_option('wc_avatax_enable_tax_calculation');
					if($this->is_plugin_active('woocommerce-avatax') && $this->option_checked('mw_wc_qbo_desk_wc_avatax_support') && $wc_avatax_enable_tax_calculation=='yes'){
						$is_avatax_active = true;
						$qbo_is_sales_tax = false;
					}
					
					if($qbo_is_sales_tax){
						if(count($tax_details)){
							$tax_rate_id = $tax_details[0]['rate_id'];
						}

						if(count($tax_details)>1){
							if($tax_details[1]['tax_amount']>0){
								$tax_rate_id_2 = $tax_details[1]['rate_id'];
							}
						}

						/*
						if(count($tax_details)>1 && $qbo_is_shipping_allowed){
							foreach($tax_details as $td){
								if($td['tax_amount']==0 && $td['shipping_tax_amount']>0){
									$qbo_tax_code_shipping = $this->get_qbo_mapped_tax_code($td['rate_id'],0);
									break;
								}
							}
						}
						*/

						$qbo_tax_code = $this->get_qbo_mapped_tax_code($tax_rate_id,$tax_rate_id_2);
						if($qbo_tax_code!='' || $qbo_tax_code!='NON'){
							$apply_tax = true;
						}
						
						//$Tax_Code_Details = $this->mod_qbo_get_tx_dtls($qbo_tax_code);
						$is_qbo_dual_tax = false;

						/*
						if(count($Tax_Code_Details)){
							if($Tax_Code_Details['TaxGroup'] && count($Tax_Code_Details['TaxRateDetail'])>1){
								$is_qbo_dual_tax = true;
							}
						}

						$Tax_Rate_Ref = (isset($Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef']:'';
						$TaxPercent = $this->get_qbo_tax_rate_value_by_key($Tax_Rate_Ref);
						$Tax_Name = (isset($Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][0]['TaxRateRef_name']:'';

						$NetAmountTaxable = 0;

						if($is_qbo_dual_tax){
							$Tax_Rate_Ref_2 = (isset($Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef']:'';
							$TaxPercent_2 = $this->get_qbo_tax_rate_value_by_key($Tax_Rate_Ref_2);
							$Tax_Name_2 = (isset($Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef']))?$Tax_Code_Details['TaxRateDetail'][1]['TaxRateRef_name']:'';
							$NetAmountTaxable_2 = 0;
						}
						*/

						/*
						if($qbo_tax_code_shipping!=''){
							$Tax_Code_Details_Shipping = $this->mod_qbo_get_tx_dtls($qbo_tax_code_shipping);
							$Tax_Rate_Ref_Shipping = (isset($Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef']:'';
							$TaxPercent_Shipping = $this->get_qbo_tax_rate_value_by_key($Tax_Rate_Ref_Shipping);
							$Tax_Name_Shipping = (isset($Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef']))?$Tax_Code_Details_Shipping['TaxRateDetail'][0]['TaxRateRef_name']:'';
							$NetAmountTaxable_Shipping = 0;
						}
						*/

						$_prices_include_tax = $this->get_array_isset($invoice_data,'_prices_include_tax','no',true);
						if($qbo_is_sales_tax){
							$tax_type = $this->get_tax_type($_prices_include_tax);
							$is_inclusive = $this->is_tax_inclusive($tax_type);
						}
					}
					
					$qbo_inv_items = (isset($invoice_data['qbo_inv_items']))?$invoice_data['qbo_inv_items']:array();
					
					if(is_array($qbo_inv_items) && count($qbo_inv_items)){
						foreach($qbo_inv_items as $qbo_item){
							$SalesOrderLine = new QuickBooks_QBXML_Object_SalesOrder_SalesOrderLine();
							//$SalesOrderLine->setItemName($qbo_item['Description']);
							$SalesOrderLine->setItemListID($qbo_item["ItemRef"]);
							if(isset($qbo_item["ClassRef"]) && $qbo_item["ClassRef"]!=''){
								$SalesOrderLine->setClassListID($qbo_item["ClassRef"]);
							}
							
							$Description = $qbo_item['Description'];
							if($this->option_checked('mw_wc_qbo_desk_add_sku_af_lid')){
								$li_item_id = ($qbo_item["variation_id"]>0)?$qbo_item["variation_id"]:$qbo_item["product_id"];
								$li_sku = get_post_meta( $li_item_id, '_sku', true );
								if($li_sku!=''){
									$Description.=' ('.$li_sku.')';
								}
							}
							
							if(!$this->option_checked('mw_wc_qbo_desk_skip_os_lid')){
								$SalesOrderLine->setDescription($Description);
							}							
							
							$UnitPrice = $qbo_item["UnitPrice"];
							$Qty = $qbo_item["Qty"];
							$Amount = $Qty*$UnitPrice;
							$SalesOrderLine->setRate($UnitPrice);
							$SalesOrderLine->setQuantity($Qty);
							$SalesOrderLine->setAmount($Amount);

							/*
							ServiceDate
							*/

							if($qbo_is_sales_tax){
								if($apply_tax && $qbo_item["Taxed"]){
									$is_tax_applied = true;
									/*$TaxCodeRef = ($qbo_company_country=='US')?'TAX':$qbo_tax_code;*/
									//$TaxCodeRef =$qbo_tax_code;
									$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_tax_rule_taxable');

									/*
									if($is_inclusive){
										$TaxInclusiveAmt = ($qbo_item['line_total']+$qbo_item['line_tax']);
									}
									*/
									if($TaxCodeRef!=''){
										$SalesOrderLine->setSalesTaxCodeListID($TaxCodeRef);
									}
								}else{
									$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
									$SalesOrderLine->setSalesTaxCodeListID($zero_rated_tax_code);
								}
							}
							
							if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync') && $qbo_item["qbo_product_type"]=='Inventory'){
								$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
								if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
									$SalesOrderLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
								}
							}

							$SalesOrder->addSalesOrderLine($SalesOrderLine);
						}
					}
					
					/*Add SalesOrder Coupons*/
					$used_coupons  = (isset($invoice_data['used_coupons']))?$invoice_data['used_coupons']:array();
					$qbo_is_discount_allowed = false;

					if(count($used_coupons)){
						foreach($used_coupons as $coupon){
							$coupon_name = $coupon['name'];
							$coupon_discount_amount = $coupon['discount_amount'];
							$coupon_discount_amount = -1 * abs($coupon_discount_amount);
							$coupon_discount_amount_tax = $coupon['discount_amount_tax'];

							$coupon_product_arr = $this->get_mapped_coupon_product($coupon_name);
							$DiscountLine = new QuickBooks_QBXML_Object_SalesOrder_SalesOrderLine();
							$DiscountLine->setItemListID($coupon_product_arr["ItemRef"]);
							if(isset($coupon_product_arr["ClassRef"]) && $coupon_product_arr["ClassRef"]!=''){
								$DiscountLine->setClassListID($coupon_product_arr["ClassRef"]);
							}
							$DiscountLine->setDescription($coupon_product_arr['Description']);
							$DiscountLine->setRate($coupon_discount_amount);
							//$DiscountLine->setQuantity(1);
							$DiscountLine->setAmount($coupon_discount_amount);

							if($qbo_is_sales_tax){
								if($coupon_discount_amount_tax > 0 || $is_tax_applied){
									//$TaxCodeRef =$qbo_tax_code;
									$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_tax_rule_taxable');
									if($TaxCodeRef!=''){
										$DiscountLine->setSalesTaxCodeListID($TaxCodeRef);
									}
								}else{
									$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
									$DiscountLine->setSalesTaxCodeListID($zero_rated_tax_code);
								}								
							}
							
							if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
								$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
								if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
									//$DiscountLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
								}
							}

							$SalesOrder->addSalesOrderLine($DiscountLine);
						}
					}
					
					/*Add SalesOrder Shipping*/
					$shipping_details  = (isset($invoice_data['shipping_details']))?$invoice_data['shipping_details']:array();

					$shipping_method = '';
					$shipping_method_name = '';
					$shipping_taxes = '';
					if(isset($shipping_details[0])){
						if($this->get_array_isset($shipping_details[0],'type','')=='shipping'){
							$shipping_method_id = $this->get_array_isset($shipping_details[0],'method_id','');
							if($shipping_method_id!=''){
								$shipping_method = $this->wc_get_sm_data_from_method_id_str($shipping_method_id);
							}
							$shipping_method = ($shipping_method=='')?'no_method_found':$shipping_method;
							$shipping_method_name =  $this->get_array_isset($shipping_details[0],'name','',true,30);
							$shipping_taxes = $this->get_array_isset($shipping_details[0],'taxes','');
						}
					}
					
					if(!$is_taxjar_active){
						//$order_shipping_total+=$_order_shipping_tax;
					}
					
					if($shipping_method!=''){
						if(!$qbo_is_shipping_allowed){
							$shipping_product_arr = $this->get_mapped_shipping_product($shipping_method);
							$ShippingLine = new QuickBooks_QBXML_Object_SalesOrder_SalesOrderLine();
							$ShippingLine->setItemListID($shipping_product_arr["ItemRef"]);
							if(isset($shipping_product_arr["ClassRef"]) && $shipping_product_arr["ClassRef"]!=''){
								$ShippingLine->setClassListID($shipping_product_arr["ClassRef"]);
							}
							$shipping_description = ($shipping_method_name!='')?'Shipping ('.$shipping_method_name.')':'Shipping';
							$ShippingLine->setDescription($shipping_description);

							$ShippingLine->setRate($order_shipping_total);
							//$ShippingLine->setQuantity(1);
							$ShippingLine->setAmount($order_shipping_total);

							if($qbo_is_sales_tax){
								if($_order_shipping_tax>0){
									//$TaxCodeRef =$qbo_tax_code;
									$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_tax_rule_taxable');
									if(empty($TaxCodeRef)){
										$TaxCodeRef = $this->get_option('mw_wc_qbo_desk_shipping_tax_rule_taxable');
									}
									
									if($TaxCodeRef!=''){
										$ShippingLine->setSalesTaxCodeListID($TaxCodeRef);
									}
								}else{
									$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
									$ShippingLine->setSalesTaxCodeListID($zero_rated_tax_code);
								}								
							}
							
							if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
								$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
								if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
									//$ShippingLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
								}
							}
							
							$SalesOrder->addSalesOrderLine($ShippingLine);

						}
					}
					
					//TaxJar Line
					if($is_taxjar_active && count($tax_details) && $_order_total_tax >0){
						$ExtLine = new QuickBooks_QBXML_Object_SalesOrder_SalesOrderLine();
						$taxjar_item = $this->get_option('mw_wc_qbo_desk_wc_taxjar_map_qbo_product');
						if(empty($taxjar_item)){
							$taxjar_item = $this->get_option('mw_wc_qbo_desk_default_qbo_item');
						}
						
						$ExtLine->setItemListID($taxjar_item);
						$ExtLine->setDescription('TaxJar - QBD Line Item');
						//$ExtLine->setRate($_order_tax);
						//$ExtLine->setQuantity(1);
						$ExtLine->setAmount($_order_total_tax);

						if($qbo_is_sales_tax){
							$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
							$ExtLine->setSalesTaxCodeListID($zero_rated_tax_code);
						}
						
						if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
							$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
							if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
								//$ExtLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
							}
						}

						$SalesOrder->addSalesOrderLine($ExtLine);
					}
					
					//Avatax Line
					if($is_avatax_active && count($tax_details) && $_order_total_tax >0){
						$ExtLine = new QuickBooks_QBXML_Object_Invoice_InvoiceLine();
						$avatax_item = $this->get_option('mw_wc_qbo_desk_wc_avatax_map_qbo_product');
						if(empty($avatax_item)){
							$avatax_item = $this->get_option('mw_wc_qbo_desk_default_qbo_item');
						}
						
						$ExtLine->setItemListID($avatax_item);
						$ExtLine->setDesc('Avatax - QBD Line Item');
						//$ExtLine->setRate($_order_tax);
						//$ExtLine->setQuantity(1);
						$ExtLine->setAmount($_order_total_tax);

						if($qbo_is_sales_tax){
							$zero_rated_tax_code = $this->get_qbo_zero_rated_tax_code($qbo_company_country);
							$ExtLine->setSalesTaxCodeListID($zero_rated_tax_code);
						}
						
						if($this->option_checked('mw_wc_qbo_desk_compt_qbd_adv_invt_sync')){
							$mw_wc_qbo_desk_compt_qbd_invt_site_ref = $this->get_option('mw_wc_qbo_desk_compt_qbd_invt_site_ref');
							if($mw_wc_qbo_desk_compt_qbd_invt_site_ref!=''){
								//$ExtLine->set('InventorySiteRef ListID' , $mw_wc_qbo_desk_compt_qbd_invt_site_ref);
							}
						}

						$SalesOrder->addInvoiceLine($ExtLine);
					}
					
					//
					if($is_tax_applied){
						$TaxCodeRef =$qbo_tax_code;
						if($TaxCodeRef!=''){
							//$SalesOrder->setSalesTaxItemListID($TaxCodeRef);
							$SalesOrder->set('ItemSalesTaxRef ListID', $TaxCodeRef);
						}
					}
					
					$is_as_addr_format = true;

					$billing_name = $this->get_array_isset($invoice_data,'_billing_first_name','',true).' '.$this->get_array_isset($invoice_data,'_billing_last_name','',true);
					$billing_name_fl = $billing_name;

					$country = $this->get_array_isset($invoice_data,'_billing_country','',true);
					$country = $this->get_country_name_from_code($country);
					//$country = '';
					
					$_billing_company = $this->get_array_isset($invoice_data,'_billing_company','',true);
					$_billing_address_1 = $this->get_array_isset($invoice_data,'_billing_address_1','',true);
					$_billing_address_2 = $this->get_array_isset($invoice_data,'_billing_address_2','',true);
					$_billing_city = $this->get_array_isset($invoice_data,'_billing_city','',true);
					$_billing_state = $this->get_array_isset($invoice_data,'_billing_state','',true);
					$_billing_postcode = $this->get_array_isset($invoice_data,'_billing_postcode','',true);
					
					$_billing_phone = $this->get_array_isset($invoice_data,'_billing_phone','',true);
					
					if(!$is_as_addr_format){
						if($_billing_company!=''){
							$SalesOrder->setBillAddress(
								$billing_name,$_billing_company,$_billing_address_1,$_billing_address_2,'',$_billing_city,$_billing_state,'',$_billing_postcode,
								$country
							);
						}else{
							$SalesOrder->setBillAddress(
								$billing_name,$_billing_address_1,$_billing_address_2,'','',$_billing_city,$_billing_state,'',$_billing_postcode,
								$country
							);
						}
					}else{
						$rfs_arr = array($this->get_array_isset($invoice_data,'_billing_first_name','',true),$this->get_array_isset($invoice_data,'_billing_last_name','',true),$_billing_company,$_billing_address_1,$_billing_address_2,$_billing_city,$_billing_state,$_billing_postcode,$_billing_phone,$country);
						$r_fa = $this->get_ord_baf_addrs($rfs_arr);
						$SalesOrder->setBillAddress(
							$this->get_array_isset($r_fa,0,'',true),
							$this->get_array_isset($r_fa,1,'',true),
							$this->get_array_isset($r_fa,2,'',true),
							$this->get_array_isset($r_fa,3,'',true),
							$this->get_array_isset($r_fa,4,'',true)
							
						);
					}
					
					if($this->get_array_isset($invoice_data,'_shipping_first_name','',true)!=''){
						$shipping_name = $this->get_array_isset($invoice_data,'_shipping_first_name','',true).' '.$this->get_array_isset($invoice_data,'_shipping_last_name','',true);

						$country = $this->get_array_isset($invoice_data,'_shipping_country','',true);
						$country = $this->get_country_name_from_code($country);
						
						$_shipping_company = $this->get_array_isset($invoice_data,'_shipping_company','',true);
						$_shipping_address_1 = $this->get_array_isset($invoice_data,'_shipping_address_1','',true);
						$_shipping_address_2 = $this->get_array_isset($invoice_data,'_shipping_address_2','',true);
						$_shipping_city = $this->get_array_isset($invoice_data,'_shipping_city','',true);
						$_shipping_state = $this->get_array_isset($invoice_data,'_shipping_state','',true);
						$_shipping_postcode = $this->get_array_isset($invoice_data,'_shipping_postcode','',true);
						
						if(!$is_as_addr_format){
							if($_shipping_company!=''){
								$SalesOrder->setShipAddress(
									$shipping_name,$_shipping_company,$_shipping_address_1,$_shipping_address_2,'',$_shipping_city,$_shipping_state,'',$_shipping_postcode,
									$country
								);
							}else{
								$SalesOrder->setShipAddress(
									$shipping_name,$_shipping_address_1,$_shipping_address_2,'','',$_shipping_city,$_shipping_state,'',$_shipping_postcode,
									$country
								);
							}
						}else{
							$rfs_arr = array($this->get_array_isset($invoice_data,'_shipping_first_name','',true),$this->get_array_isset($invoice_data,'_shipping_last_name','',true),$_shipping_company,$_shipping_address_1,$_shipping_address_2,$_shipping_city,$_shipping_state,$_shipping_postcode,$country);
							$r_fa = $this->get_ord_saf_addrs($rfs_arr);
							$SalesOrder->setShipAddress(
								$this->get_array_isset($r_fa,0,'',true),
								$this->get_array_isset($r_fa,1,'',true),
								$this->get_array_isset($r_fa,2,'',true),
								$this->get_array_isset($r_fa,3,'',true),
								$this->get_array_isset($r_fa,4,'',true)
								
							);
						}						
						
					}
					
					$customer_note = $this->get_array_isset($invoice_data,'customer_note','');
					if($this->option_checked('mw_wc_qbo_desk_invoice_memo')){
						$SalesOrder->setMemo($customer_note);
					}
					
					if($this->option_checked('mw_wc_qbo_desk_cname_into_memo')){
						$cname_memo = $billing_name_fl;
						$SalesOrder->setMemo($cname_memo);
					}
					
					//New - Extra Fields
					$mw_wc_qbo_desk_ord_push_rep_othername = $this->get_option('mw_wc_qbo_desk_ord_push_rep_othername');
					if($mw_wc_qbo_desk_ord_push_rep_othername!=''){
						$SalesOrder->setSalesRepListID($mw_wc_qbo_desk_ord_push_rep_othername);
					}
					
					if($this->is_plugin_active('woocommerce-gateway-purchase-order') && $this->option_checked('mw_wc_qbo_desk_wpopg_po_support')){
						//if($_payment_method == 'woocommerce_gateway_purchase_order'){}
						$_po_number = $this->get_array_isset($invoice_data,'_po_number','',true);
						if($_po_number!=''){
							$SalesOrder->setPONumber($_po_number);
						}else{
							$SalesOrder->setPONumber('Web');
						}
					}
					
					$mw_wc_qbo_desk_ord_push_entered_by = $this->get_option('mw_wc_qbo_desk_ord_push_entered_by');
					if($mw_wc_qbo_desk_ord_push_entered_by!=''){
						$SalesOrder->setOther($mw_wc_qbo_desk_ord_push_entered_by);
					}
					
					if($this->wacs_base_cur_enabled()){					
						$base_currency = get_woocommerce_currency();
						$pm_map_data = $this->get_mapped_payment_method_data($_payment_method,$base_currency);
					}else{
						$pm_map_data = $this->get_mapped_payment_method_data($_payment_method,$_order_currency);
					}
					
					$term_id_str = $this->get_array_isset($pm_map_data,'term_id_str','',true);
					if($term_id_str!=''){
						$SalesOrder->setTermsListID($term_id_str);
					}
					
					//$this->_p($SalesOrder);
					
					$qbxml = $SalesOrder->asQBXML(QUICKBOOKS_ADD_SALESORDER,null,$this->get_qbxml_locale());
					$qbxml = $this->get_qbxml_prefix().$qbxml. $this->get_qbxml_suffix();					

					return $qbxml;
					
					/**/
				}
			}
		}
	}
	
	//31-10-2017
	public function get_ord_baf_addrs($ba_data){
		//$f_ba_data = array('line1'=>'','line2'=>'','line3'=>'','line4'=>'','line5'=>'');
		$f_ba_data = array();
		if(is_array($ba_data) && count($ba_data)){				
			$mw_wc_qbo_desk_ord_bill_addr_map = $this->get_option('mw_wc_qbo_desk_ord_bill_addr_map');
			if(empty($mw_wc_qbo_desk_ord_bill_addr_map)){
				$mw_wc_qbo_desk_ord_bill_addr_map = $this->get_default_ord_ba();
			}
			$fs_srch_arr = array('{_billing_first_name}','{_billing_last_name}','{_billing_company}','{_billing_address_1}','{_billing_address_2}','{_billing_city}','{_billing_state}','{_billing_postcode}','{_billing_phone}','{_billing_country}');
			$fsa_arr = explode(PHP_EOL,$mw_wc_qbo_desk_ord_bill_addr_map);
			
			//$this->_p($fs_srch_arr);
			//$this->_p($fsa_arr);
			//$this->_p($ba_data);
			
			if(is_array($fsa_arr) && count($fsa_arr)){
				foreach($fsa_arr as $sk => $sd){
					if($sk>4){break;}
					//$sk_c = $sk+1;
					$sd = trim($sd);
					$fxa = str_replace($fs_srch_arr,$ba_data,$sd);
					$fxa = trim($fxa);
					//$f_ba_data['line'.$sk_c] = $fxa;
					$f_ba_data[] = $fxa;
				}
			}
		}
		$f_ba_data = array_filter($f_ba_data);
		$f_ba_data = array_values($f_ba_data);
		//$this->_p($f_ba_data);
		return $f_ba_data;
	}
	
	public function get_ord_saf_addrs($sa_data){		
		//$f_sa_data = array('line1'=>'','line2'=>'','line3'=>'','line4'=>'','line5'=>'');
		$f_sa_data = array();
		if(is_array($sa_data) && count($sa_data)){
			$mw_wc_qbo_desk_ord_ship_addr_map = $this->get_option('mw_wc_qbo_desk_ord_ship_addr_map');
			if(empty($mw_wc_qbo_desk_ord_ship_addr_map)){
				$mw_wc_qbo_desk_ord_ship_addr_map = $this->get_default_ord_sa();
			}
			
			$fs_srch_arr = array('{_shipping_first_name}','{_shipping_last_name}','{_shipping_company}','{_shipping_address_1}','{_shipping_address_2}','{_shipping_city}','{_shipping_state}','{_shipping_postcode}','{_shipping_country}');
			$fsa_arr = explode(PHP_EOL,$mw_wc_qbo_desk_ord_ship_addr_map); 
			
			//$this->_p($fs_srch_arr);
			//$this->_p($fsa_arr);
			//$this->_p($sa_data);
			
			if(is_array($fsa_arr) && count($fsa_arr)){
				foreach($fsa_arr as $sk => $sd){
					if($sk>4){break;}
					//$sk_c = $sk+1;
					$sd = trim($sd);
					$fxa = str_replace($fs_srch_arr,$sa_data,$sd);
					$fxa = trim($fxa);
					//$f_sa_data['line'.$sk_c] = $fxa;
					$f_sa_data[] = $fxa;
				}
			}
		}
		$f_sa_data = array_filter($f_sa_data);
		$f_sa_data = array_values($f_sa_data);
	
		//$this->_p($f_sa_data);
		return $f_sa_data;
	}
	
	public function GetCustomerQbxml($id,$is_guest=false){
		if($this->is_qwc_connected()){

			if($is_guest){
				$order_id = (int) $id;
				$customer_data = $this->get_wc_customer_info_from_order($order_id);
			}else{
				$customer_id = (int) $id;
				$customer_data = $this->get_wc_customer_info($customer_id);
			}

			if(is_array($customer_data) && count($customer_data)){
				$Customer = new QuickBooks_QBXML_Object_Customer();

				$Customer->setFirstName($customer_data['firstname']);
				$Customer->setLastName($customer_data['lastname']);
				//
				$display_name = $customer_data['display_name'];
				global $wpdb;
				
				if($this->option_checked('mw_wc_qbo_desk_cus_push_append_client_id')){
					if($this->get_field_by_val($wpdb->prefix.'mw_wc_qbo_desk_qbd_customers','qbd_customerid','d_name',$display_name)){
						if($is_guest){
							if($customer_data['email']!=''){
								$display_name.= '-'.$order_id;
							}							
						}else{
							$display_name.= '-'.$customer_id;
						}						
					}
				}
				
				
				$Customer->setName($display_name);
				$Customer->setCompanyName($customer_data['company']);
				$Customer->setEmail($customer_data['email']);
				
				$f_l_name = $customer_data['firstname'].' '.$customer_data['lastname'];
				
				//New - Extra Fields
				$mw_wc_qbo_desk_cus_push_customertype = $this->get_option('mw_wc_qbo_desk_cus_push_customertype');
				if($mw_wc_qbo_desk_cus_push_customertype!=''){
					$Customer->setCustomerTypeListID($mw_wc_qbo_desk_cus_push_customertype);
				}
				
				$mw_wc_qbo_desk_cus_push_rep_othername = $this->get_option('mw_wc_qbo_desk_cus_push_rep_othername');
				if($mw_wc_qbo_desk_cus_push_rep_othername!=''){
					$Customer->setSalesRepListID($mw_wc_qbo_desk_cus_push_rep_othername);
				}
				
				$phone = $this->get_array_isset($customer_data,'billing_phone','',true,21);
				if($phone!=''){
					$Customer->setPhone($phone);
				}

				$address = $this->get_array_isset($customer_data,'billing_address_1','',true);
				if($address!=''){
					$country = $this->get_array_isset($customer_data,'billing_country','',true);
					$country = $this->get_country_name_from_code($country);
					//$country = '';

					$Customer->setBillAddress(
					$f_l_name,
					$address,
					$this->get_array_isset($customer_data,'billing_address_2','',true),
					
					'',
					'',
					$this->get_array_isset($customer_data,'billing_city','',true),
					$this->get_array_isset($customer_data,'billing_state','',true),
					'',
					$this->get_array_isset($customer_data,'billing_postcode','',true),
					$country
					);
				}

				$shipping_address = $this->get_array_isset($customer_data,'shipping_address_1','',true);
				if($shipping_address!=''){
					$country = $this->get_array_isset($customer_data,'shipping_country','',true);
					$country = $this->get_country_name_from_code($country);

					$Customer->setShipAddress(
					$f_l_name,
					$shipping_address,
					$this->get_array_isset($customer_data,'shipping_address_2','',true),
					
					'',
					'',
					$this->get_array_isset($customer_data,'shipping_city','',true),
					$this->get_array_isset($customer_data,'shipping_state','',true),
					'',
					$this->get_array_isset($customer_data,'shipping_postcode','',true),
					$country
					);
				}

				$qbxml = $Customer->asQBXML(QUICKBOOKS_ADD_CUSTOMER,null,$this->get_qbxml_locale());
				$qbxml = $this->get_qbxml_prefix().$qbxml. $this->get_qbxml_suffix();
				return $qbxml;
			}
		}
	}
	
	public function GetProductQbxml($id,$type='',$is_variation=0){
		if($this->is_qwc_connected()){
			if($is_variation){
				$product_data = $this->get_wc_variation_info($id);
			}else{
				$product_data = $this->get_wc_product_info($id);
			}
			//$this->_p($product_data);
			if(is_array($product_data) && count($product_data)){
				if($type=='NonInventory'){
					$Product = new QuickBooks_QBXML_Object_NonInventoryItem();
				}
				
				if($type=='Inventory'){
					$Product = new QuickBooks_QBXML_Object_InventoryItem();
				}
				
				if($type=='Service'){
					$Product = new QuickBooks_QBXML_Object_ServiceItem();
				}
				
				$name_replace_chars = array(':');
				$name = $this->get_array_isset($product_data,'name','',true,100,false,$name_replace_chars);
				$sku = $this->get_array_isset($product_data,'_sku','',true);
				
				if($sku!=''){
					$Product->setName($sku);
				}else{
					$Product->setName($name);
				}				
				
				$desc = $this->get_array_isset($product_data,'short_description','',true,4000);
				if($desc==''){
					$desc = $this->get_array_isset($product_data,'description','',true,4000);
				}
				
				$_price = $this->get_array_isset($product_data,'_price',0);
				$_price = str_replace(',','',$_price);
				$_price = floatval($_price);
				
				
				
				$qbo_product_account = $this->get_option('mw_wc_qbo_desk_default_qbo_product_account');				
				
				//setPrice#setDescription#setAccountListID#setPurchaseDescription#setExpenseAccountListID#setPreferredVendorListID#setFullName#setIsActive
				
				if($type=='NonInventory'){
					if($sku!=''){
						$Product->setDescription($name);
					}else{
						$Product->setDescription($desc);
					}
					
					$Product->setPrice($_price);
					
					$Product->setAccountListID($qbo_product_account);
					//$this->_p($Product);
					$qbxml = $Product->asQBXML(QUICKBOOKS_ADD_NONINVENTORYITEM,null,$this->get_qbxml_locale());
				}
				
				if($type=='Inventory'){
					if($sku!=''){
						$Product->setSalesDescription($name);
					}else{
						$Product->setSalesDescription($desc);
					}
					
					$Product->setSalesPrice($_price);
					
					$_stock = $this->get_array_isset($product_data,'_stock',0,true);
					if($_stock==''){$_stock=0;}
					$Product->setQuantityOnHand($_stock);
					
					$Product->setIncomeAccountListID($qbo_product_account);
					
					//
					$qbo_product_account_asset = $this->get_option('mw_wc_qbo_desk_default_qbo_asset_account');
					if($qbo_product_account_asset!=''){
						$Product->setAssetAccountListID($qbo_product_account_asset);
					}
					
					$qbo_product_account_cogs = $this->get_option('mw_wc_qbo_desk_default_qbo_cogs_account');
					if($qbo_product_account_cogs!=''){
						$Product->setCOGSAccountListID($qbo_product_account_cogs);
					}
					
					$qbxml = $Product->asQBXML(QUICKBOOKS_ADD_INVENTORYITEM,null,$this->get_qbxml_locale());
				}
				
				if($type=='Service'){
					if($sku!=''){
						$Product->setDescription($name);
					}else{
						$Product->setDescription($desc);
					}
					
					$Product->setPrice($_price);
					
					$Product->setAccountListID($qbo_product_account);
					
					$qbxml = $Product->asQBXML(QUICKBOOKS_ADD_SERVICEITEM,null,$this->get_qbxml_locale());
				}
				
				//$this->_p($Product);
				$qbxml = $this->get_qbxml_prefix().$qbxml. $this->get_qbxml_suffix();
				return $qbxml;
				
			}
		}
	}
	
	public function GetInventoryAdjustmentAddQbxml($id,$is_variation=0){
		if($this->is_qwc_connected()){
			if($is_variation){
				$product_data = $this->get_wc_variation_info($id);
			}else{
				$product_data = $this->get_wc_product_info($id);
			}
			
			if(is_array($product_data) && count($product_data)){
				$quickbook_product_id = $this->if_qbo_product_exists($product_data,true);
				if(!empty($quickbook_product_id)){
					$InventoryAdjustment = new QuickBooks_QBXML_Object_InventoryAdjustment();
					
					$_stock = $this->get_array_isset($product_data,'_stock',0,true);
					if($_stock==''){$_stock=0;}
					
					$qbo_product_account_asset = $this->get_option('mw_wc_qbo_desk_default_qbo_asset_account');
					$InventoryAdjustment->setAccountListID($qbo_product_account_asset);
					
					$InventoryAdjustmentLine = new QuickBooks_QBXML_Object_InventoryAdjustment_InventoryAdjustmentLine();
					$InventoryAdjustmentLine->setLineItemListID($quickbook_product_id);
					$InventoryAdjustmentLine->setLineQuantityNew($_stock);
					
					$InventoryAdjustment->addInventoryAdjustmentLine($InventoryAdjustmentLine);
					
					$qbxml = $InventoryAdjustment->asQBXML('InventoryAdjustmentAdd',null,$this->get_qbxml_locale());
					$qbxml = str_replace('<NewQuantity></NewQuantity>','<NewQuantity>0</NewQuantity>',$qbxml);
					$qbxml = $this->get_qbxml_prefix('13.0').$qbxml. $this->get_qbxml_suffix();
					return $qbxml;
				}				
			}
		}
	}
	
	public function GetPaymentQbxml($id){
		if($this->is_qwc_connected()){			
			global $wpdb;
			$_transaction_id = $this->get_field_by_val($wpdb->postmeta,'meta_value','meta_id',$id);
			$order_id = (int) $this->get_field_by_val($wpdb->postmeta,'post_id','meta_id',$id);
			
			$payment_data = $this->wc_get_payment_details_by_txn_id($_transaction_id,$order_id);
			
			//$this->_p($payment_data);
			if(is_array($payment_data) && count($payment_data)){
				if($this->option_checked('mw_wc_qbo_desk_order_as_sales_receipt')){
					return false;
				}
				
				$qbd_sa = 'Invoice';
				if($this->option_checked('mw_wc_qbo_desk_order_as_sales_order')){
					//$qbd_sa = 'SalesOrder';
					return false;
				}
				
				$_payment_method = $this->get_array_isset($payment_data,'payment_method','',true);
				$_payment_method_title = $this->get_array_isset($payment_data,'payment_method_title','',true);
				
				$_order_currency = $this->get_array_isset($payment_data,'order_currency','',true);
				if($this->wacs_base_cur_enabled()){
					//$p_order_details = $this->get_wc_order_details_from_order($order_id,get_post($order_id));
					$base_currency = get_woocommerce_currency();
					$pm_map_data = $this->get_mapped_payment_method_data($_payment_method,$base_currency);
				}else{
					$pm_map_data = $this->get_mapped_payment_method_data($_payment_method,$_order_currency);
				}
				
				//$this->_p($pm_map_data);
				$enable_payment = (int) $this->get_array_isset($pm_map_data,'enable_payment',0);
				if($this->wacs_base_cur_enabled()){
					//$payment_amount = get_post_meta($order_id,'_order_total_base_currency',true);
					$payment_amount = $this->get_order_base_currency_total_from_order_id($order_id);
				}else{
					$payment_amount = $this->get_array_isset($payment_data,'order_total',0);
				}
				
				$payment_amount = floatval($payment_amount);
				
				$is_valid_payment = false;
				if($enable_payment && $payment_amount>0){
					$is_valid_payment = true;
				}
				
				if(!$is_valid_payment){return false;}
				
				$manual = $this->get_array_isset($payment_data,'manual',false);
				$payment_id = (int) $this->get_array_isset($payment_data,'payment_id',0);
				$wc_inv_id = (int) $this->get_array_isset($payment_data,'order_id',0);
				$wc_cus_id = (int) $this->get_array_isset($payment_data,'customer_user',0);
				
				if(!$payment_id){
					$this->save_log(array('log_type'=>'Payment','log_title'=>'Export Payment Error #'.$payment_id,'details'=>'Woocommerce payment id not found','status'=>0));
					return false;
				}
				
				/*
				$wc_inv_no = '';
				if($this->is_plugin_active('woocommerce-sequential-order-numbers-pro','woocommerce-sequential-order-numbers') && $this->option_checked('mw_wc_qbo_sync_compt_p_wsnop')){
					if($this->is_plugin_active('woocommerce-sequential-order-numbers')){
						$wc_inv_no = get_post_meta( $wc_inv_id, '_order_number', true );
					}else{
						$wc_inv_no = get_post_meta( $wc_inv_id, '_order_number_formatted', true );
					}
					
				}
				*/
				
				$qbd_invoice_id = $this->check_quickbooks_invoice($wc_inv_id);
				
				if(!$qbd_invoice_id){
					$this->save_log(array('log_type'=>'Payment','log_title'=>'Export Payment Error #'.$payment_id,'details'=>'QuickBooks '.strtolower($qbd_sa).' not found','status'=>0));
					return false;
				}
				
				$qbo_cus_id = '';
				if($this->is_plugin_active('woocommerce-aelia-currencyswitcher') && $this->option_checked('mw_wc_qbo_desk_wacs_satoc_cb')){				
					if($_order_currency!=''){
						$aelia_cur_cus_map = get_option('mw_wc_qbo_desk_wacs_satoc_map_cur_cus');
						if(is_array($aelia_cur_cus_map) && count($aelia_cur_cus_map)){
							if(isset($aelia_cur_cus_map[$_order_currency]) && trim($aelia_cur_cus_map[$_order_currency])!=''){
								$qbo_cus_id = trim($aelia_cur_cus_map[$_order_currency]);
							}
						}
					}					
				}
				
				if(empty($qbo_cus_id)){
					if(!$this->option_checked('mw_wc_qbo_desk_all_order_to_customer')){
						if($wc_cus_id>0){
							//$qbo_cus_id = $this->get_wc_data_pair_val('Customer',$wc_cus_id);
							if($this->option_checked('mw_wc_qbo_desk_customer_qbo_check_billing_company')){
								$customer_data = $this->get_wc_customer_info_from_order($order_id);
							}else{
								$customer_data = $this->get_wc_customer_info($wc_cus_id);
							}
							
							$qbo_cus_id = $this->if_qbo_customer_exists($customer_data);
						}else{
							$customer_data = $this->get_wc_customer_info_from_order($order_id);
							$qbo_cus_id = $this->if_qbo_guest_exists($customer_data);
						}
					}else{
						if($wc_cus_id>0){
							$user_info = get_userdata($wc_cus_id);
							$io_cs = false;
							if(isset($user_info->roles) && is_array($user_info->roles)){
								$sc_roles_as_cus = $this->get_option('mw_wc_qbo_desk_wc_cust_role_sync_as_cus');
								if(!empty($sc_roles_as_cus)){
									$sc_roles_as_cus = explode(',',$sc_roles_as_cus);
									if(is_array($sc_roles_as_cus) && count($sc_roles_as_cus)){
										foreach($sc_roles_as_cus as $sr){
											if(in_array($sr,$user_info->roles)){
												$io_cs = true;
												break;
											}
										}
									}
								}
							}
							
							if($io_cs){
								if($this->option_checked('mw_wc_qbo_desk_customer_qbo_check_billing_company')){
									$customer_data = $this->get_wc_customer_info_from_order($order_id);
								}else{
									$customer_data = $this->get_wc_customer_info($wc_cus_id);
								}							
								$qbo_cus_id = $this->if_qbo_customer_exists($customer_data);
							}else{
								$qbo_cus_id = $this->get_option('mw_wc_qbo_desk_customer_to_sync_all_orders');
							}
							
						}else{
							$qbo_cus_id = $this->get_option('mw_wc_qbo_desk_customer_to_sync_all_orders');
						}				
					}
				}				
				
				if(empty($qbo_cus_id)){
					$this->save_log(array('log_type'=>'Customer','log_title'=>'Export Payment Error #'.$payment_id,'details'=>'QuickBooks Customer Not Found','status'=>0));
					return false;
				}				
				
				$ReceivePayment = new QuickBooks_QBXML_Object_ReceivePayment();
				$ReceivePayment->setCustomerListID($qbo_cus_id);
				
				$_paid_date = $this->get_array_isset($payment_data,'paid_date','',true);
				$_paid_date = $this->format_date($_paid_date);
				
				$ReceivePayment->setTxnDate($_paid_date);
				$_transaction_id = $this->get_array_isset($payment_data,'transaction_id','',true);
				
				$qb_p_method_id = $this->get_array_isset($pm_map_data,'qb_p_method_id',0);
				$qbo_account_id = $this->get_array_isset($pm_map_data,'qbo_account_id',0);
				
				if($_transaction_id!=''){
					$ReceivePayment->setRefNumber($_transaction_id);
				}else{
					$ReceivePayment->setRefNumber($payment_id);
				}				
				
				$AppliedToTxn = new QuickBooks_QBXML_Object_ReceivePayment_AppliedToTxn();
				$AppliedToTxn->setTxnID($qbd_invoice_id);
				$AppliedToTxn->setPaymentAmount($payment_amount);
				
				$ReceivePayment->addAppliedToTxn($AppliedToTxn);
				
				$ReceivePayment->setTotalAmount($payment_amount);
				//setARAccountListID
				$ReceivePayment->setPaymentMethodListID($qb_p_method_id);
				$ReceivePayment->setDepositToAccountListID($qbo_account_id);
				//setMemos
				
				$qbxml = $ReceivePayment->asQBXML('ReceivePaymentAdd',null,$this->get_qbxml_locale());
				$qbxml = $this->get_qbxml_prefix().$qbxml. $this->get_qbxml_suffix();

				return $qbxml;
				
			}
		}
	}
	
	/*Sync Functions*/
	
	public function AddInventoryItemRequest($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$is_variation = $this->get_array_isset($extra,'is_variation',0,true);
		$qbxml = $this->GetProductQbxml($ID,'Inventory',$is_variation);
		
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			if($is_variation){
				$dlog_txt = PHP_EOL .'Product Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			}else{
				$dlog_txt = PHP_EOL .'Variation Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			}
			$dlog_txt.=$qbxml;
			$this->add_test_log($dlog_txt);
		}
		
		return $qbxml;
	}
	
	public function AddNonInventoryRequest($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$is_variation = $this->get_array_isset($extra,'is_variation',0,true);
		$qbxml = $this->GetProductQbxml($ID,'NonInventory',$is_variation);
		
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			if($is_variation){
				$dlog_txt = PHP_EOL .'Product Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			}else{
				$dlog_txt = PHP_EOL .'Variation Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			}			
			$dlog_txt.=$qbxml;
			$this->add_test_log($dlog_txt);
		}
		return $qbxml;
	}
	
	public function AddServiceItemRequest($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$is_variation = $this->get_array_isset($extra,'is_variation',0,true);
		$qbxml = $this->GetProductQbxml($ID,'Service',$is_variation);
		
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			if($is_variation){
				$dlog_txt = PHP_EOL .'Product Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			}else{
				$dlog_txt = PHP_EOL .'Variation Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			}
			$dlog_txt.=$qbxml;
			$this->add_test_log($dlog_txt);
		}
		return $qbxml;
	}
	
	public function AddInventoryItemResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$this->AddProductResponse($requestID, $user, $action, $ID, $extra, $err, $last_action_time, $last_actionident_time, $xml, $idents);
		return true;
	}
	
	public function AddNonInventoryResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$this->AddProductResponse($requestID, $user, $action, $ID, $extra, $err, $last_action_time, $last_actionident_time, $xml, $idents);
		return true;
	}
	
	public function AddServiceItemResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$this->AddProductResponse($requestID, $user, $action, $ID, $extra, $err, $last_action_time, $last_actionident_time, $xml, $idents);
		return true;
	}
	
	public function AddProductResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		//$this->add_test_log($xml);
		//$this->add_test_log(print_r($idents,true));
		$is_variation = $this->get_array_isset($extra,'is_variation',0,true);
		
		if(is_array($idents) && isset($idents['ListID']) && $idents['ListID']!=''){
			if($is_variation){
				$this->save_data_pair('Variation',$ID,$idents['ListID']);
			}else{
				$this->save_data_pair('Product',$ID,$idents['ListID']);
			}
			$lg_type = ($is_variation)?'Variation':'Product';
			
			$this->save_item_map($ID,$idents['ListID'],$is_variation);
			$this->save_qbo_item_local($idents['ListID'],$ID,$is_variation);
			
			$details = "{$lg_type} #{$ID} added into quickbooks successfully".PHP_EOL;
			$details.="QuickBooks List ID #".$idents['ListID'];
			$this->save_log(array('log_type'=>$lg_type,'log_title'=>'Export '.$lg_type.' #'.$ID,'details'=>$details,'status'=>1),true);
		}else{
			$details = "Error:$err";
			$this->save_log(array('log_type'=>$lg_type,'log_title'=>'Export '.$lg_type.' Error #'.$ID,'details'=>$details,'status'=>0),true);
		}
		return true;
	}
	
	public function InventoryAdjustmentAddRequest($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$is_variation = $this->get_array_isset($extra,'is_variation',0,true);
		$qbxml = $this->GetInventoryAdjustmentAddQbxml($ID,$is_variation);
		
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			if($is_variation){
				$dlog_txt = PHP_EOL .'Variation Inventiory Update Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			}else{
				$dlog_txt = PHP_EOL .'Inventiory Update Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			}
			
			$dlog_txt.=$qbxml;
			$this->add_test_log($dlog_txt);
		}
		return $qbxml;
	}
	
	public function InventoryAdjustmentAddResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}		
		//$this->add_test_log($xml);
		//$this->add_test_log(print_r($idents,true));
		
		if(is_array($idents) && isset($idents['ListID']) && $idents['ListID']!=''){
			$is_variation = $this->get_array_isset($extra,'is_variation',0,true);
			$ext_lt = ($is_variation)?'Variation ':'';
			
			$details = "{$ext_lt}Inventory #{$ID} updated into quickbooks successfully".PHP_EOL;
			$details.="QuickBooks List ID #".$idents['ListID'];
			$this->save_log(array('log_type'=>'Inventory','log_title'=>'Update '.$ext_lt.'Inventory #'.$ID,'details'=>$details,'status'=>1),true);
		}else{
			$details = "Error:$err";
			$this->save_log(array('log_type'=>'Inventory','log_title'=>'Update '.$ext_lt.'Inventory Error #'.$ID,'details'=>$details,'status'=>0),true);
		}
		return true;
	}
	
	
	public function AddCustomerRequest($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$qbxml = $this->GetCustomerQbxml($ID);
		
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'Customer Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$qbxml;
			$this->add_test_log($dlog_txt);
		}
		return $qbxml;
	}

	public function AddCustomerResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		//$this->add_test_log($xml);
		//$this->add_test_log(print_r($idents,true));

		if(is_array($idents) && isset($idents['ListID']) && $idents['ListID']!=''){
			$this->save_data_pair('Customer',$ID,$idents['ListID']);
			$this->save_customer_map($ID,$idents['ListID']);
			$this->save_qbo_customer_local($idents['ListID'],$ID);
			$details = "Customer #{$ID} added into quickbooks successfully".PHP_EOL;
			$details.="QuickBooks List ID #".$idents['ListID'];
			$this->save_log(array('log_type'=>'Customer','log_title'=>'Export Customer #'.$ID,'details'=>$details,'status'=>1),true);
		}else{
			$details = "Error:$err";
			$this->save_log(array('log_type'=>'Customer','log_title'=>'Export Customer Error #'.$ID,'details'=>$details,'status'=>0),true);
		}
		return true;
	}

	public function AddGuestRequest($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$qbxml = $this->GetCustomerQbxml($ID,true);
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'Customer/Guest Add Request Order #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$qbxml;
			$this->add_test_log($dlog_txt);
		}
		return $qbxml;
	}

	public function AddGuestResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		//$this->add_test_log($xml);
		//$this->add_test_log(print_r($idents,true));

		if(is_array($idents) && isset($idents['ListID']) && $idents['ListID']!=''){
			$customer_data = $this->get_wc_customer_info_from_order($ID);
			$this->save_qbo_customer_local($idents['ListID'],null,$customer_data);

			$details = "Customer added into quickbooks successfully".PHP_EOL;
			$details.="QuickBooks List ID #".$idents['ListID'].PHP_EOL;
			$details.="Order ID #{$ID}";
			$this->save_log(array('log_type'=>'Customer','log_title'=>'Export Guest/Customer','details'=>$details,'status'=>1),true);
		}else{
			$details = "Error:$err".PHP_EOL;
			$details.="Order ID #{$ID}";
			$this->save_log(array('log_type'=>'Customer','log_title'=>'Export Guest/Customer Error','details'=>$details,'status'=>0),true);
		}
		return true;
	}
	
	/*Payment Sync*/
	public function AddPaymentRequest($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$qbxml = $this->GetPaymentQbxml($ID);
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'Payment Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$qbxml;
			$this->add_test_log($dlog_txt);
		}
		return $qbxml;
	}
	
	public function AddPaymentResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		//$this->add_test_log($xml);
		//$this->add_test_log(print_r($idents,true));

		if(is_array($idents) && isset($idents['TxnID']) && $idents['TxnID']!=''){
			$this->save_data_pair('Payment',$ID,$idents['TxnID']);
			$details = "Payment #{$ID} added into quickbooks successfully".PHP_EOL;
			$details.="QuickBooks TxnID #".$idents['TxnID'];
			$this->save_log(array('log_type'=>'Payment','log_title'=>'Export Payment #'.$ID,'details'=>$details,'status'=>1),true);
		}else{
			$details = "Error:$err";
			$this->save_log(array('log_type'=>'Payment','log_title'=>'Export Payment Error #'.$ID,'details'=>$details,'status'=>0),true);
		}
		return true;
	}

	/*Invoice Sync*/
	public function AddInvoiceRequest($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$qbxml = $this->GetInvoiceQbxml($ID);
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'Invoice Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$qbxml;
			$this->add_test_log($dlog_txt);
		}
		return $qbxml;
	}
	
	public function AddSalesReceiptRequest($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$qbxml = $this->GetSalesReceiptQbxml($ID);
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'SalesReceipt Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$qbxml;
			$this->add_test_log($dlog_txt);
		}
		return $qbxml;
	}

	public function AddSalesOrderRequest($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		$qbxml = $this->GetSalesOrderQbxml($ID);
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'SalesOrder Add Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$qbxml;
			$this->add_test_log($dlog_txt);
		}
		return $qbxml;
	}
	
	public function AddInvoiceResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		//$this->add_test_log($xml);
		//$this->add_test_log(print_r($idents,true));

		if(is_array($idents) && isset($idents['TxnID']) && $idents['TxnID']!=''){
			$this->save_data_pair('Order',$ID,$idents['TxnID']);
			$details = "Order #{$ID} added into quickbooks successfully".PHP_EOL;
			$details.="QuickBooks TxnID #".$idents['TxnID'];
			$this->save_log(array('log_type'=>'Order','log_title'=>'Export Order #'.$ID,'details'=>$details,'status'=>1),true);
		}else{
			$details = "Error:$err";
			$this->save_log(array('log_type'=>'Order','log_title'=>'Export Order Error #'.$ID,'details'=>$details,'status'=>0),true);
		}
		return true;
	}
	
	public function AddSalesReceiptResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		//$this->add_test_log($xml);
		//$this->add_test_log(print_r($idents,true));

		if(is_array($idents) && isset($idents['TxnID']) && $idents['TxnID']!=''){
			$this->save_data_pair('Order',$ID,$idents['TxnID']);
			$details = "Order #{$ID} added into quickbooks successfully".PHP_EOL;
			$details.="QuickBooks TxnID #".$idents['TxnID'];
			$this->save_log(array('log_type'=>'Order','log_title'=>'Export Order #'.$ID,'details'=>$details,'status'=>1),true);
		}else{
			$details = "Error:$err";
			$this->save_log(array('log_type'=>'Order','log_title'=>'Export Order Error #'.$ID,'details'=>$details,'status'=>0),true);
		}
		return true;
	}
	
	public function AddSalesOrderResponse($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		//$this->add_test_log($xml);
		//$this->add_test_log(print_r($idents,true));

		if(is_array($idents) && isset($idents['TxnID']) && $idents['TxnID']!=''){
			$this->save_data_pair('Order',$ID,$idents['TxnID']);
			$details = "Order #{$ID} added into quickbooks successfully".PHP_EOL;
			$details.="QuickBooks TxnID #".$idents['TxnID'];
			$this->save_log(array('log_type'=>'Order','log_title'=>'Export Order #'.$ID,'details'=>$details,'status'=>1),true);
		}else{
			$details = "Error:$err";
			$this->save_log(array('log_type'=>'Order','log_title'=>'Export Order Error #'.$ID,'details'=>$details,'status'=>0),true);
		}
		return true;
	}

	/*Errors And Hooks Function Start*/
	public function Qwc_Catch_All_Errors($requestID, $user, $action, $ID, $extra, &$err, $xml, $errnum, $errmsg){
		//$this->add_test_log($errmsg);
		$log_type = '';$log_status = 0;$log_title = '';$details = '';
		switch ($action) {
			case "InvoiceAdd":
				$log_type = 'Order';
				$log_title = 'Export Order Error #'.$ID;

				break;
			case "CustomerAdd":
				$log_type = 'Customer';
				$log_title = 'Export Customer Error #'.$ID;
				break;
				
			case "ItemInventoryAdd":
				$log_type = 'Product';
				$log_title = 'Export Product Error #'.$ID;
				break;
				
			case "ItemNonInventoryAdd":
				$log_type = 'Product';
				$log_title = 'Export Product Error #'.$ID;
				break;
			
			case "ItemServiceAdd":
				$log_type = 'Product';
				$log_title = 'Export Product Error #'.$ID;
				break;
				
			case "ReceivePaymentAdd":
				$log_type = 'Payment';
				$log_title = 'Export Payment Error #'.$ID;
				break;
				
			case "ItemInventoryMod":
				$log_type = 'Inventory';
				$log_title = 'Update Inventory Error #'.$ID;
				break;
			
			/*Import Errors*/
			
			case "CustomerImport":
				$log_type = 'Customer';
				$log_title = 'Import Customer Error';
				break;
			case "ItemImport":
				$log_type = 'Product';
				$log_title = 'Import Product Error';
				break;
			case "AccountImport":
				$log_type = 'Account';
				$log_title = 'Import Account Error';
				break;
			case "TermsImport":
				$log_type = 'Terms';
				$log_title = 'Import Terms Error';
				break;
			case "SalesTaxCodeImport":
				$log_type = 'SalesTaxCode';
				$log_title = 'Import SalesTaxCode Error';
				break;
			case "ClassImport":
				$log_type = 'Class';
				$log_title = 'Import Class Error';
				break;
			case "PaymentMethodImport":
				$log_type = 'PaymentMethod';
				$log_title = 'Import PaymentMethod Error';
				break;
			case "AUTO_WC_UPDATE_INVENTORY":
				$log_type = 'InventoryPull';
				$log_title = 'Auto Import Inventory Error';
				break;
			default:
				$log_type = 'Other';
				$log_title = $action.' Error';
		}

		$details.= "Error Number:{$errnum}".PHP_EOL;
		$details.= "Error:{$errmsg}";

		if($log_title!=''){
			$this->save_log(array('log_type'=>$log_type,'log_title'=>$log_title,'details'=>$details,'status'=>$log_status),true);
		}
		return true;
	}

	public function Hook_Login_Success($requestID, $user, $hook, &$err, $hook_data, $callback_config){
		if(!$this->is_qwc_connected()){
			return false;
		}

		$this->save_log(array('log_type'=>'Web Connector','log_title'=>'Web Connector Login Success','details'=>'New Web Connector Request Authenticated Successfully','status'=>1));

		//QuickBooks_Utilities::log($this->dsn, 'User logged in: ' . $user . ', params: ' . print_r($hook_data, true));

		$qbd_import = false;$extra_import = false;

		if($this->option_checked('mw_wc_qbo_desk_cp_refresh_data_enable')){
			$qbd_import = true;
		}

		if($this->option_checked('mw_wc_qbo_desk_oth_refresh_data_enable')){
			$extra_import = true;
		}
		
		if($qbd_import || $extra_import || $this->option_checked('mw_wc_qbo_desk_rt_pull_enable')){
			$Queue = QuickBooks_WebConnector_Queue_Singleton::getInstance();
			//$Queue = new QuickBooks_WebConnector_Queue($this->get_dsn());
			$date = date('Y-m-d H:i:s');
		}

		if($qbd_import){
			if($this->check_refresh_data_enabled_by_item('customer')){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_CUSTOMER)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_CUSTOMER, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_CUSTOMER, null, QB_PRIORITY_CUSTOMER,null,$this->get_qbun());
			}

			if($this->check_refresh_data_enabled_by_item('product')){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_ITEM)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_ITEM, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_ITEM, null, QB_PRIORITY_ITEM,null,$this->get_qbun());
			}

		}

		if($extra_import){
			$priority = QB_PRIORITY_EXTRA;

			/*PaymentMethod Import Queue*/

			if($this->check_refresh_data_enabled_by_item('payment_method',true)){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_PAYMENTMETHOD)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_PAYMENTMETHOD, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_PAYMENTMETHOD, null, $priority,null,$this->get_qbun());
			}


			/*Account Import Queue*/
			if($this->check_refresh_data_enabled_by_item('account',true)){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_ACCOUNT)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_ACCOUNT, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_ACCOUNT, null, $priority,null,$this->get_qbun());
			}

			/*Class Import Queue*/
			if($this->check_refresh_data_enabled_by_item('class',true)){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_CLASS)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_CLASS, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_CLASS, null, $priority,null,$this->get_qbun());
			}

			/*SalesTaxCode Import Queue*/
			if($this->check_refresh_data_enabled_by_item('sales_tax_code',true)){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_SALESTAXCODE)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_SALESTAXCODE, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_SALESTAXCODE, null, $priority,null,$this->get_qbun());
			}

			/*Term Import Queue*/
			if($this->check_refresh_data_enabled_by_item('term',true)){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_TERMS)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_TERMS, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_TERMS, null, $priority,null,$this->get_qbun());
			}

			/*Preferences Import Queue*/
			if($this->check_refresh_data_enabled_by_item('preferences',true)){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_PREFERENCES)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_PREFERENCES, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_PREFERENCES, null, $priority,null,$this->get_qbun());
				$Queue->enqueue(QUICKBOOKS_IMPORT_COMPANY, null, $priority,null,$this->get_qbun());
			}
			
			/*InventorySite Import Queue*/
			if($this->check_refresh_data_enabled_by_item('InventorySite',true)){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_INVENTORYSITE)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_INVENTORYSITE, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_INVENTORYSITE, null, $priority,null,$this->get_qbun());
			}
			
			/*OtherName Import Queue*/
			if($this->check_refresh_data_enabled_by_item('OtherName',true)){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_OTHERNAME)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_OTHERNAME, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_OTHERNAME, null, $priority,null,$this->get_qbun());
			}
			
			/*SalesRep Import Queue*/
			if($this->check_refresh_data_enabled_by_item('SalesRep',true)){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_SALESREP)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_SALESREP, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_SALESREP, null, $priority,null,$this->get_qbun());
			}
			
			/*CustomerType Import Queue*/
			if($this->check_refresh_data_enabled_by_item('CustomerType',true)){
				if (!$this->_quickbooks_get_last_run($user, QUICKBOOKS_IMPORT_CUSTOMERTYPE)){
					$this->_quickbooks_set_last_run($user, QUICKBOOKS_IMPORT_CUSTOMERTYPE, $date);
				}
				$Queue->enqueue(QUICKBOOKS_IMPORT_CUSTOMERTYPE, null, $priority,null,$this->get_qbun());
			}

			//delete_option('mw_wc_qbo_sync_cp_refresh_data_enable');
			//delete_option('mw_wc_qbo_sync_oth_refresh_data_enable');

		}
		
		/*Auto Pull Queue*/
		
		if($this->option_checked('mw_wc_qbo_desk_rt_pull_enable')){
			if($this->check_if_real_time_pull_enable_for_item('inventory')){
				if (!$this->_quickbooks_get_last_run($user, 'AUTO_WC_UPDATE_INVENTORY')){
					$this->_quickbooks_set_last_run($user, 'AUTO_WC_UPDATE_INVENTORY', $date);
				}
				$Queue->enqueue('AUTO_WC_UPDATE_INVENTORY', null, 0,null,$this->get_qbun());
			}
		}		
	}
	/*Errors And Hooks Function End*/
	
	/*Pull Functions Start*/
	
	public function Pull_Update_Wc_Product_Price_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		
		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<ItemQueryRq  requestID="' . $requestID . '">			
						<ListID >'.$ID.'</ListID>
						<OwnerID>0</OwnerID>
					</ItemQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';		
		
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'Product Price Import Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$xml;
			//$this->add_test_log($dlog_txt);
		}
		
		return $xml;
	}
	
	public function Pull_Update_Wc_Inventory_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		
		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<ItemInventoryQueryRq  requestID="' . $requestID . '">			
						<ListID >'.$ID.'</ListID>
						<OwnerID>0</OwnerID>
					</ItemInventoryQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';		
		
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'Inventory Import Request #'.$ID.' - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$xml;
			//$this->add_test_log($dlog_txt);
		}
		
		return $xml;
	}
	
	/*Date Functions*/	
	public function get_qbd_cdt_now($time_zone=''){
		if(empty($time_zone)){
			$time_zone = $this->get_qbd_timezone();
		}
		$now = new DateTime(null, new DateTimeZone($time_zone));
		$datetime = $now->format('Y-m-d H:i:s');
		
		return $datetime;
	}
	
	public function get_auto_inventory_pull_m_dt_from($time_zone=''){
		global $wpdb;
		if(empty($time_zone)){
			$time_zone = $this->get_qbd_timezone();
		}
		
		$mw_qbo_dts_qwc_sec_interval = (int) $this->get_option('mw_qbo_dts_qwc_sec_interval'); //In Seconds
		$minute_interval = floor(($mw_qbo_dts_qwc_sec_interval / 60));
		
		$now = new DateTime(null, new DateTimeZone($time_zone));
		$datetime = $now->format('Y-m-d H:i:s');
		//$timestamp_to = date('Y-m-d', strtotime($datetime)) . 'T' . date('H:i:s', strtotime($datetime));
		
		$rt_ii_it_val = $this->get_option('mw_wc_qbo_desk_rt_inventory_import_interval_time');		
		
		switch ($rt_ii_it_val) {
			case "c_i_t":
				$datetime = date('Y-m-d H:i:s',strtotime("-{$minute_interval} minutes",strtotime($datetime)));
				break;
			case "l_1_h":
				$datetime = date('Y-m-d H:i:s',strtotime("-60 minutes",strtotime($datetime)));
				break;
			case "l_1_d":
				$datetime = date('Y-m-d H:i:s',strtotime("-1 days",strtotime($datetime)));
				break;
			case "l_i_s_t":
				$datetime = $this->get_option('mw_wc_qbo_desk_rt_inventory_p_s_time');
				$datetime = $this->convert_dt_timezone($datetime,$time_zone);
				break;
			case "l_w_c_a_s_t":
				$dq = "SELECT `added_date` FROM {$wpdb->prefix}mw_wc_qbo_desk_qbd_log  WHERE `log_title` = 'Web Connector Login Success' AND `log_type` = 'Web Connector' ORDER BY `id` DESC LIMIT 0,1 ";
				$datetime = $wpdb->get_var($dq);
				$datetime = $this->convert_dt_timezone($datetime,$time_zone);
				break;
			default:
				$datetime = date('Y-m-d H:i:s',strtotime("-{$minute_interval} minutes",strtotime($datetime)));
		}
		
		if(empty($datetime)){
			$datetime = date('Y-m-d H:i:s',strtotime("-{$minute_interval} minutes",strtotime($datetime)));
		}
		
		$timestamp_from = date('Y-m-d', strtotime($datetime)) . 'T' . date('H:i:s', strtotime($datetime));
		return $timestamp_from;
	}
	
	/*New Inventory Auto Pull*/
	public function Auto_Wc_Inventory_AdjustmentQuery_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		
		$attr_iteratorID = '';
		$attr_iterator = ' iterator="Start" ';
		if (empty($extra['iteratorID'])){
			$last = $this->_quickbooks_get_last_run($user, $action);
			$this->_quickbooks_set_last_run($user, $action);
			$this->_quickbooks_set_current_run($user, $action, $last);
		}else{
			$attr_iteratorID = ' iteratorID="' . $extra['iteratorID'] . '" ';
			$attr_iterator = ' iterator="Continue" ';

			$last = $this->_quickbooks_get_current_run($user, $action);
		}		
		
		$timestamp_from = $this->get_auto_inventory_pull_m_dt_from($this->get_qbd_timezone());
		
		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<InventoryAdjustmentQueryRq ' . $attr_iterator . ' ' . $attr_iteratorID . ' requestID="' . $requestID . '">
						<MaxReturned>' . QB_QUICKBOOKS_MAX_RETURNED . '</MaxReturned>
						
						<ModifiedDateRangeFilter>
							<FromModifiedDate >'.$timestamp_from.'</FromModifiedDate>										
						</ModifiedDateRangeFilter>
						
						<IncludeLineItems >true</IncludeLineItems>
						<IncludeRetElement >InventoryAdjustmentLineRet</IncludeRetElement>
					</InventoryAdjustmentQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';
		
		/*
		<ModifiedDateRangeFilter>
			<FromModifiedDate >'.$timestamp_from.'</FromModifiedDate>
			<ToModifiedDate >DATETIMETYPE</ToModifiedDate>			
		</ModifiedDateRangeFilter>		
		*/
		
		/*
		<TxnDateRangeFilter>
			<FromTxnDate >'.$timestamp_from.'</FromTxnDate>
			<ToTxnDate >DATETYPE</ToTxnDate>
			<DateMacro >Today</DateMacro>
		</TxnDateRangeFilter>
		*/
		
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'Auto Inventory Import Request - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$xml;
			$this->add_test_log($dlog_txt);
		}
		return $xml;
	}
	
	public function Auto_Wc_Inventory_AdjustmentQuery_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		//$this->add_test_log('Auto Inventory Import XML Response'.PHP_EOL .$xml);
		if(!$this->is_qwc_connected()){
			return false;
		}
		
		global $wpdb;
		
		if (!empty($idents['iteratorRemainingCount'])){
			$Queue = QuickBooks_WebConnector_Queue_Singleton::getInstance();
			$Queue->enqueue('AUTO_WC_UPDATE_INVENTORY', null, 0, array( 'iteratorID' => $idents['iteratorID'] ),$this->get_qbun());
		}
		
		$iteratorID = (isset($idents['iteratorID']) && !empty($idents['iteratorID']))?$idents['iteratorID']:'';
		
		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);
		
		$tot_updated = 0;
		$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_items';
		
		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/InventoryAdjustmentQueryRs');
			
			foreach ($List->children() as $Item){
				foreach ($Item->children() as $Item_C){
					if($Item_C->name() == 'InventoryAdjustmentLineRet'){
						$ret = $Item_C->name();						
						$ItemRef = $Item_C->getChildDataAt($ret . ' ItemRef ListID');
						$this->Add_Pull_Inventory_Queue($ItemRef);
					}					
				}
			}
		}
		
		return true;
		
	}	
	
	
	public function Auto_Pull_Update_Wc_Inventory_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}
		
		$attr_iteratorID = '';
		$attr_iterator = ' iterator="Start" ';
		if (empty($extra['iteratorID'])){
			$last = $this->_quickbooks_get_last_run($user, $action);
			$this->_quickbooks_set_last_run($user, $action);
			$this->_quickbooks_set_current_run($user, $action, $last);
		}else{
			$attr_iteratorID = ' iteratorID="' . $extra['iteratorID'] . '" ';
			$attr_iterator = ' iterator="Continue" ';

			$last = $this->_quickbooks_get_current_run($user, $action);
		}		
		
		$timestamp_from = $this->get_auto_inventory_pull_m_dt_from($this->get_qbd_timezone());
		
		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<ItemInventoryQueryRq ' . $attr_iterator . ' ' . $attr_iteratorID . ' requestID="' . $requestID . '">
						<MaxReturned>' . QB_QUICKBOOKS_MAX_RETURNED . '</MaxReturned>
						<FromModifiedDate>' . $timestamp_from . '</FromModifiedDate>
						<OwnerID>0</OwnerID>
					</ItemInventoryQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';
		
		/*ToModifiedDate*/
		
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'Auto Inventory Import Request - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$xml;
			$this->add_test_log($dlog_txt);
		}
		return $xml;
	}
	
	public function Pull_Update_Wc_Product_Price_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		
		global $wpdb;
		
		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);
		
		$tot_updated = 0;
		$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_items';
		
		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/ItemQueryRs');
			
			foreach ($List->children() as $Item){
				$type = substr(substr($Item->name(), 0, -3), 4);
				$ret = $Item->name();
				
				$ListID = $Item->getChildDataAt($ret . ' ListID');
				$Name = $Item->getChildDataAt($ret . ' Name');
				$Price = $Item->getChildDataAt($ret . 'Price');
				
				if(empty($Price)){
					$Price = $Item->getChildDataAt($ret . 'SalesOrPurchase Price');
				}
				
				if(empty($Price)){
					$Price = $Item->getChildDataAt($ret . 'SalesAndPurchase SalesPrice');
				}
				
				if(empty($Price)){
					$Price = $Item->getChildDataAt($ret . 'SalesPrice');
				}
				
				$uwi_data = array();
				$uwi_data['qbo_product_id'] = $ListID;
				$uwi_data['Name'] = $Name;
				$uwi_data['Price'] = $Price;
				
				if(is_array($extra) && count($extra) && isset($extra['manual']) && $extra['manual']){
					$uwi_data['manual'] = true;
				}
				
				$this->UpdateWooCommerceProductPrice($uwi_data);
				
				//Update Local Table Data
				$arr = array(
				'ListID' => $Item->getChildDataAt($ret . ' ListID'),
				'TimeCreated' => $Item->getChildDataAt($ret . ' TimeCreated'),
				'TimeModified' => $Item->getChildDataAt($ret . ' TimeModified'),
				'Name' => $Item->getChildDataAt($ret . ' Name'),
				'FullName' => $Item->getChildDataAt($ret . ' FullName'),
				'Type' => $type,
				'Parent_ListID' => $Item->getChildDataAt($ret . ' ParentRef ListID'),
				'Parent_FullName' => $Item->getChildDataAt($ret . ' ParentRef FullName'),
				'ManufacturerPartNumber' => $Item->getChildDataAt($ret . ' ManufacturerPartNumber'),
				'SalesTaxCode_ListID' => $Item->getChildDataAt($ret . ' SalesTaxCodeRef ListID'),
				'SalesTaxCode_FullName' => $Item->getChildDataAt($ret . ' SalesTaxCodeRef FullName'),
				'BuildPoint' => $Item->getChildDataAt($ret . ' BuildPoint'),
				'ReorderPoint' => $Item->getChildDataAt($ret . ' ReorderPoint'),
				'QuantityOnHand' => $Item->getChildDataAt($ret . ' QuantityOnHand'),
				'AverageCost' => $Item->getChildDataAt($ret . ' AverageCost'),
				'QuantityOnOrder' => $Item->getChildDataAt($ret . ' QuantityOnOrder'),
				'QuantityOnSalesOrder' => $Item->getChildDataAt($ret . ' QuantityOnSalesOrder'),
				'TaxRate' => $Item->getChildDataAt($ret . ' TaxRate'),
				'Price' => $Item->getChildDataAt($ret . ' Price'),
				);

				$look_for = array(
				'SalesPrice' => array( 'SalesOrPurchase Price', 'SalesAndPurchase SalesPrice', 'SalesPrice' ),
				'SalesDesc' => array( 'SalesOrPurchase Desc', 'SalesAndPurchase SalesDesc', 'SalesDesc' ),
				'PurchaseCost' => array( 'SalesOrPurchase Price', 'SalesAndPurchase PurchaseCost', 'PurchaseCost' ),
				'PurchaseDesc' => array( 'SalesOrPurchase Desc', 'SalesAndPurchase PurchaseDesc', 'PurchaseDesc' ),
				'PrefVendor_ListID' => array( 'SalesAndPurchase PrefVendorRef ListID', 'PrefVendorRef ListID' ),
				'PrefVendor_FullName' => array( 'SalesAndPurchase PrefVendorRef FullName', 'PrefVendorRef FullName' ),
				);

				foreach ($look_for as $field => $look_here){
					if (!empty($arr[$field])){
						break;
					}

					foreach ($look_here as $look){
						$arr[$field] = $Item->getChildDataAt($ret . ' ' . $look);
					}
				}
				
				$id = (int) $this->get_field_by_val($table,'id','qbd_id',$ListID);
				
				$save_data = array();				
				$save_data['name'] = $arr['Name'];
				$save_data['sku'] = '';
				$save_data['product_type'] = $arr['Type'];
				$save_data['parent_id'] = $arr['Parent_ListID'];

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				if($id>0){
					$wpdb->update($table,$save_data,array('id'=>$id),'',array('%d'));
				}else{
					$save_data['qbd_id'] = $arr['ListID'];
					$wpdb->insert($table, $save_data);
				}
			}
		}
		
		return true;
	}
	
	public function Auto_Pull_Update_Wc_Inventory_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		
		global $wpdb;
		
		if (!empty($idents['iteratorRemainingCount'])){
			$Queue = QuickBooks_WebConnector_Queue_Singleton::getInstance();
			$Queue->enqueue('AUTO_WC_UPDATE_INVENTORY', null, 0, array( 'iteratorID' => $idents['iteratorID'] ),$this->get_qbun());
		}
		
		$iteratorID = (isset($idents['iteratorID']) && !empty($idents['iteratorID']))?$idents['iteratorID']:'';
		
		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);
		
		$tot_updated = 0;
		$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_items';
		
		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/ItemInventoryQueryRs');
			
			foreach ($List->children() as $Item){
				$type = substr(substr($Item->name(), 0, -3), 4);
				$ret = $Item->name();
				
				$ListID = $Item->getChildDataAt($ret . ' ListID');
				$Name = $Item->getChildDataAt($ret . ' Name');
				$QuantityOnHand = $Item->getChildDataAt($ret . ' QuantityOnHand');
				
				$uwi_data = array();
				$uwi_data['qbo_inventory_id'] = $ListID;
				$uwi_data['Name'] = $Name;
				$uwi_data['QuantityOnHand'] = $QuantityOnHand;
				
				if(is_array($extra) && count($extra) && isset($extra['manual']) && $extra['manual']){
					$uwi_data['manual'] = true;
				}
				
				$this->UpdateWooCommerceInventory($uwi_data);
				
				//Update Local Table Data
				$arr = array(
				'ListID' => $Item->getChildDataAt($ret . ' ListID'),
				'TimeCreated' => $Item->getChildDataAt($ret . ' TimeCreated'),
				'TimeModified' => $Item->getChildDataAt($ret . ' TimeModified'),
				'Name' => $Item->getChildDataAt($ret . ' Name'),
				'FullName' => $Item->getChildDataAt($ret . ' FullName'),
				'Type' => $type,
				'Parent_ListID' => $Item->getChildDataAt($ret . ' ParentRef ListID'),
				'Parent_FullName' => $Item->getChildDataAt($ret . ' ParentRef FullName'),
				'ManufacturerPartNumber' => $Item->getChildDataAt($ret . ' ManufacturerPartNumber'),
				'SalesTaxCode_ListID' => $Item->getChildDataAt($ret . ' SalesTaxCodeRef ListID'),
				'SalesTaxCode_FullName' => $Item->getChildDataAt($ret . ' SalesTaxCodeRef FullName'),
				'BuildPoint' => $Item->getChildDataAt($ret . ' BuildPoint'),
				'ReorderPoint' => $Item->getChildDataAt($ret . ' ReorderPoint'),
				'QuantityOnHand' => $Item->getChildDataAt($ret . ' QuantityOnHand'),
				'AverageCost' => $Item->getChildDataAt($ret . ' AverageCost'),
				'QuantityOnOrder' => $Item->getChildDataAt($ret . ' QuantityOnOrder'),
				'QuantityOnSalesOrder' => $Item->getChildDataAt($ret . ' QuantityOnSalesOrder'),
				'TaxRate' => $Item->getChildDataAt($ret . ' TaxRate'),
				'Price' => $Item->getChildDataAt($ret . ' Price'),
				);

				$look_for = array(
				'SalesPrice' => array( 'SalesOrPurchase Price', 'SalesAndPurchase SalesPrice', 'SalesPrice' ),
				'SalesDesc' => array( 'SalesOrPurchase Desc', 'SalesAndPurchase SalesDesc', 'SalesDesc' ),
				'PurchaseCost' => array( 'SalesOrPurchase Price', 'SalesAndPurchase PurchaseCost', 'PurchaseCost' ),
				'PurchaseDesc' => array( 'SalesOrPurchase Desc', 'SalesAndPurchase PurchaseDesc', 'PurchaseDesc' ),
				'PrefVendor_ListID' => array( 'SalesAndPurchase PrefVendorRef ListID', 'PrefVendorRef ListID' ),
				'PrefVendor_FullName' => array( 'SalesAndPurchase PrefVendorRef FullName', 'PrefVendorRef FullName' ),
				);

				foreach ($look_for as $field => $look_here){
					if (!empty($arr[$field])){
						break;
					}

					foreach ($look_here as $look){
						$arr[$field] = $Item->getChildDataAt($ret . ' ' . $look);
					}
				}
				
				$id = (int) $this->get_field_by_val($table,'id','qbd_id',$ListID);
				
				$save_data = array();				
				$save_data['name'] = $arr['Name'];
				$save_data['sku'] = '';
				$save_data['product_type'] = $arr['Type'];
				$save_data['parent_id'] = $arr['Parent_ListID'];

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				if($id>0){
					$wpdb->update($table,$save_data,array('id'=>$id),'',array('%d'));
				}else{
					$save_data['qbd_id'] = $arr['ListID'];
					$wpdb->insert($table, $save_data);
				}
			}
		}
		
		return true;
	}
	
	public function Pull_Update_Wc_Inventory_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!is_array($extra)){
			$extra = array();
		}
		
		$extra['manual'] = true;
		$this->Auto_Pull_Update_Wc_Inventory_Response($requestID, $user, $action, $ID, $extra, $err, $last_action_time, $last_actionident_time, $xml, $idents);
	}
	
	/*Pull Functions End*/

	/*Import Functions Start*/

	/*Customer Import Request/Response*/
	public function Customer_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		$attr_iteratorID = '';
		$attr_iterator = ' iterator="Start" ';
		if (empty($extra['iteratorID'])){
			$last = $this->_quickbooks_get_last_run($user, $action);
			$this->_quickbooks_set_last_run($user, $action);
			$this->_quickbooks_set_current_run($user, $action, $last);
		}else{
			$attr_iteratorID = ' iteratorID="' . $extra['iteratorID'] . '" ';
			$attr_iterator = ' iterator="Continue" ';

			$last = $this->_quickbooks_get_current_run($user, $action);
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<CustomerQueryRq ' . $attr_iterator . ' ' . $attr_iteratorID . ' requestID="' . $requestID . '">
						<MaxReturned>' . QB_QUICKBOOKS_MAX_RETURNED . '</MaxReturned>
						<!--<FromModifiedDate>' . $last . '</FromModifiedDate>-->
						<OwnerID>0</OwnerID>
					</CustomerQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';
		
		/*
		if($this->option_checked('mw_wc_qbo_desk_add_xml_req_into_log')){
			$dlog_txt = PHP_EOL .'Customer Import Request - '.$this->get_cdt(). PHP_EOL;
			$dlog_txt.=$xml;
			$this->add_test_log($dlog_txt);
		}
		*/
		
		return $xml;

	}

	public function Customer_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);
		//$this->add_test_log(print_r($idents,true));
		global $wpdb;
		if (!empty($idents['iteratorRemainingCount'])){
			$Queue = QuickBooks_WebConnector_Queue_Singleton::getInstance();
			$Queue->enqueue(QUICKBOOKS_IMPORT_CUSTOMER, null, QB_PRIORITY_CUSTOMER, array( 'iteratorID' => $idents['iteratorID'] ),$this->get_qbun());
		}

		$iteratorID = (isset($idents['iteratorID']) && !empty($idents['iteratorID']))?$idents['iteratorID']:'';

		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/CustomerQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_customers';

			/*Delete Old Data*/
			if($this->get_session_val('import_customer_iteratorID','',true)!=$iteratorID){
				$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
				$wpdb->query("TRUNCATE TABLE {$table}");
			}

			//
			$this->set_session_val('import_customer_iteratorID',$iteratorID);

			foreach ($List->children() as $Customer){
				$tot_imported++;
				$arr = array(
				'ListID' => $Customer->getChildDataAt('CustomerRet ListID'),
				'TimeCreated' => $Customer->getChildDataAt('CustomerRet TimeCreated'),
				'TimeModified' => $Customer->getChildDataAt('CustomerRet TimeModified'),
				'Email' => $Customer->getChildDataAt('CustomerRet Email'),
				'Name' => $Customer->getChildDataAt('CustomerRet Name'),
				'FullName' => $Customer->getChildDataAt('CustomerRet FullName'),
				'FirstName' => $Customer->getChildDataAt('CustomerRet FirstName'),
				'MiddleName' => $Customer->getChildDataAt('CustomerRet MiddleName'),
				'LastName' => $Customer->getChildDataAt('CustomerRet LastName'),
				'Contact' => $Customer->getChildDataAt('CustomerRet Contact'),
				'CompanyName' => $Customer->getChildDataAt('CustomerRet CompanyName'),

				'BillAddress_Addr1' => $Customer->getChildDataAt('CustomerRet BillAddress Addr1'),
				'BillAddress_Addr2' => $Customer->getChildDataAt('CustomerRet BillAddress Addr2'),
				'BillAddress_City' => $Customer->getChildDataAt('CustomerRet BillAddress City'),
				'BillAddress_State' => $Customer->getChildDataAt('CustomerRet BillAddress State'),
				'BillAddress_PostalCode' => $Customer->getChildDataAt('CustomerRet BillAddress PostalCode'),
				'BillAddress_Country' => $Customer->getChildDataAt('CustomerRet BillAddress Country'),

				'ShipAddress_Addr1' => $Customer->getChildDataAt('CustomerRet ShipAddress Addr1'),
				'ShipAddress_Addr2' => $Customer->getChildDataAt('CustomerRet ShipAddress Addr2'),
				'ShipAddress_City' => $Customer->getChildDataAt('CustomerRet ShipAddress City'),
				'ShipAddress_State' => $Customer->getChildDataAt('CustomerRet ShipAddress State'),
				'ShipAddress_PostalCode' => $Customer->getChildDataAt('CustomerRet ShipAddress PostalCode'),
				'ShipAddress_Country' => $Customer->getChildDataAt('CustomerRet ShipAddress Country'),
				);

				//QuickBooks_Utilities::log($this->dsn, 'Importing customer ' . $arr['FullName'] . ': ' . print_r($arr, true));
				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_customerid'] = $arr['ListID'];
				$save_data['email'] = $arr['Email'];
				$save_data['first_name'] = $arr['FirstName'];
				$save_data['middle_name'] = $arr['MiddleName'];
				$save_data['last_name'] = $arr['LastName'];
				$save_data['company'] = $arr['CompanyName'];
				$save_data['d_name'] = $arr['Name'];
				$save_data['info_arr'] = serialize($arr);
				
				/*Now storing xml insted of qbxml obj due to serialize issue*/
				//$save_data['info_qbxml_obj'] = serialize($Customer);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				//$this->add_test_log(print_r($save_data,true));
				$wpdb->insert($table, $save_data);
				//$lastid = $wpdb->insert_id;
				//$this->add_test_log($wpdb->last_error);

			}
		}

		if($tot_imported>0){
			$log_title = "Import Customer Successfully";
			$details = "Total Customer Imported:{$tot_imported}";
			$status = 1;
			
			//Clear Invalid Mappings
			$this->clear_customer_invalid_mappings();
		}else{
			$log_title = "Import Customer Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No Customer Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";
			$status = 0;
		}
		$this->save_log(array('log_type'=>'Customer','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}

	/*Product Import Request/Response*/
	public function Item_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		$attr_iteratorID = '';
		$attr_iterator = ' iterator="Start" ';
		if (empty($extra['iteratorID'])){
			$last = $this->_quickbooks_get_last_run($user, $action);
			$this->_quickbooks_set_last_run($user, $action);
			$this->_quickbooks_set_current_run($user, $action, $last);
		}else{
			$attr_iteratorID = ' iteratorID="' . $extra['iteratorID'] . '" ';
			$attr_iterator = ' iterator="Continue" ';

			$last = $this->_quickbooks_get_current_run($user, $action);
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<ItemQueryRq ' . $attr_iterator . ' ' . $attr_iteratorID . ' requestID="' . $requestID . '">
						<MaxReturned>' . QB_QUICKBOOKS_MAX_RETURNED . '</MaxReturned>
						<!--<FromModifiedDate>' . $last . '</FromModifiedDate>-->
						<OwnerID>0</OwnerID>
					</ItemQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;
	}

	public function Item_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);
		global $wpdb;

		if (!empty($idents['iteratorRemainingCount'])){
			$Queue = QuickBooks_WebConnector_Queue_Singleton::getInstance();
			$Queue->enqueue(QUICKBOOKS_IMPORT_ITEM, null, QB_PRIORITY_ITEM, array( 'iteratorID' => $idents['iteratorID'] ),$this->get_qbun());
		}

		$iteratorID = (isset($idents['iteratorID']) && !empty($idents['iteratorID']))?$idents['iteratorID']:'';

		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/ItemQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_items';

			/*Delete Old Data*/
			if($this->get_session_val('import_product_iteratorID','',true)!=$iteratorID){
				$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
				$wpdb->query("TRUNCATE TABLE {$table}");
			}

			//
			$this->set_session_val('import_product_iteratorID',$iteratorID);

			foreach ($List->children() as $Item){
				$tot_imported++;
				$type = substr(substr($Item->name(), 0, -3), 4);
				$ret = $Item->name();

				$arr = array(
				'ListID' => $Item->getChildDataAt($ret . ' ListID'),
				'TimeCreated' => $Item->getChildDataAt($ret . ' TimeCreated'),
				'TimeModified' => $Item->getChildDataAt($ret . ' TimeModified'),
				'Name' => $Item->getChildDataAt($ret . ' Name'),
				'FullName' => $Item->getChildDataAt($ret . ' FullName'),
				'Type' => $type,
				'Parent_ListID' => $Item->getChildDataAt($ret . ' ParentRef ListID'),
				'Parent_FullName' => $Item->getChildDataAt($ret . ' ParentRef FullName'),
				'ManufacturerPartNumber' => $Item->getChildDataAt($ret . ' ManufacturerPartNumber'),
				'SalesTaxCode_ListID' => $Item->getChildDataAt($ret . ' SalesTaxCodeRef ListID'),
				'SalesTaxCode_FullName' => $Item->getChildDataAt($ret . ' SalesTaxCodeRef FullName'),
				'BuildPoint' => $Item->getChildDataAt($ret . ' BuildPoint'),
				'ReorderPoint' => $Item->getChildDataAt($ret . ' ReorderPoint'),
				'QuantityOnHand' => $Item->getChildDataAt($ret . ' QuantityOnHand'),
				'AverageCost' => $Item->getChildDataAt($ret . ' AverageCost'),
				'QuantityOnOrder' => $Item->getChildDataAt($ret . ' QuantityOnOrder'),
				'QuantityOnSalesOrder' => $Item->getChildDataAt($ret . ' QuantityOnSalesOrder'),
				'TaxRate' => $Item->getChildDataAt($ret . ' TaxRate'),
				'Price' => $Item->getChildDataAt($ret . ' Price'),
				);

				$look_for = array(
				'SalesPrice' => array( 'SalesOrPurchase Price', 'SalesAndPurchase SalesPrice', 'SalesPrice' ),
				'SalesDesc' => array( 'SalesOrPurchase Desc', 'SalesAndPurchase SalesDesc', 'SalesDesc' ),
				'PurchaseCost' => array( 'SalesOrPurchase Price', 'SalesAndPurchase PurchaseCost', 'PurchaseCost' ),
				'PurchaseDesc' => array( 'SalesOrPurchase Desc', 'SalesAndPurchase PurchaseDesc', 'PurchaseDesc' ),
				'PrefVendor_ListID' => array( 'SalesAndPurchase PrefVendorRef ListID', 'PrefVendorRef ListID' ),
				'PrefVendor_FullName' => array( 'SalesAndPurchase PrefVendorRef FullName', 'PrefVendorRef FullName' ),
				);

				foreach ($look_for as $field => $look_here){
					if (!empty($arr[$field])){
						break;
					}

					foreach ($look_here as $look){
						$arr[$field] = $Item->getChildDataAt($ret . ' ' . $look);
					}
				}
				//QuickBooks_Utilities::log($this->dsn, 'Importing ' . $type . ' Item ' . $arr['FullName'] . ': ' . print_r($arr, true));
				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_id'] = $arr['ListID'];
				$save_data['name'] = $arr['Name'];
				$save_data['sku'] = '';
				$save_data['product_type'] = $arr['Type'];
				$save_data['parent_id'] = $arr['Parent_ListID'];

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = serialize($Item);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				$wpdb->insert($table, $save_data);
				//$lastid = $wpdb->insert_id;

			}
		}

		if($tot_imported>0){
			$log_title = "Import Product Successfully";
			$details = "Total Product Imported:{$tot_imported}";
			$status = 1;
			
			//Clear Invalid Mappings
			$this->clear_product_invalid_mappings();
			$this->clear_variation_invalid_mappings();
		}else{
			$log_title = "Import Product Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No Product Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";
			$status = 0;
		}
		$this->save_log(array('log_type'=>'Product','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}

	/*PaymentMethod Import Request/Response*/
	public function PaymentMethod_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<PaymentMethodQueryRq requestID="' . $requestID . '">
					</PaymentMethodQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}

	public function PaymentMethod_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);

		global $wpdb;

		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/PaymentMethodQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_list_paymentmethod';

			/*Delete Old Data*/
			$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
			$wpdb->query("TRUNCATE TABLE {$table}");

			foreach ($List->children() as $PaymentMethod){
				$tot_imported++;
				$arr = array(
				'ListID' => $PaymentMethod->getChildDataAt('PaymentMethodRet ListID'),
				'Name' => $PaymentMethod->getChildDataAt('PaymentMethodRet Name'),
				'IsActive' => $PaymentMethod->getChildDataAt('PaymentMethodRet IsActive'),
				'PaymentMethodType' => $PaymentMethod->getChildDataAt('PaymentMethodRet PaymentMethodType'),
				);

				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_id'] = $arr['ListID'];
				$save_data['name'] = $arr['Name'];
				$save_data['pm_type'] = $arr['PaymentMethodType'];
				$save_data['is_active'] = ($arr['IsActive']=='true')?1:0;

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = serialize($PaymentMethod);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				$wpdb->insert($table, $save_data);
				//$lastid = $wpdb->insert_id;

			}
		}

		if($tot_imported>0){
			$log_title = "Import PaymentMethod Successfully";
			$details = "Total PaymentMethod Imported:{$tot_imported}";
			$status = 1;
		}else{
			$log_title = "Import PaymentMethod Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No PaymentMethod Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";
			$status = 0;
		}
		$this->save_log(array('log_type'=>'PaymentMethod','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}

	/*Account Import Request/Response*/
	public function Account_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<AccountQueryRq requestID="' . $requestID . '">
						<OwnerID>0</OwnerID>
					</AccountQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}

	public function Account_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);

		global $wpdb;

		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/AccountQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_list_account';

			/*Delete Old Data*/
			$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
			$wpdb->query("TRUNCATE TABLE {$table}");

			foreach ($List->children() as $Account){
				$tot_imported++;
				$arr = array(
				'ListID' => $Account->getChildDataAt('AccountRet ListID'),
				'Name' => $Account->getChildDataAt('AccountRet Name'),
				'FullName' => $Account->getChildDataAt('AccountRet FullName'),
				'IsActive' => $Account->getChildDataAt('AccountRet IsActive'),
				'AccountType' => $Account->getChildDataAt('AccountRet AccountType'),
				'AccountNumber' => $Account->getChildDataAt('AccountRet AccountNumber'),
				'Desc' => $Account->getChildDataAt('AccountRet Desc'),
				'Balance' => $Account->getChildDataAt('AccountRet Balance'),
				'TotalBalance' => $Account->getChildDataAt('AccountRet TotalBalance'),
				'IsActive' => $Account->getChildDataAt('AccountRet IsActive'),
				);

				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_id'] = $arr['ListID'];
				$save_data['name'] = $arr['Name'];
				$save_data['acc_type'] = $arr['AccountType'];
				$save_data['acc_num'] = $arr['AccountNumber'];
				$save_data['is_active'] = ($arr['IsActive']=='true')?1:0;

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = serialize($Account);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				$wpdb->insert($table, $save_data);
				//$lastid = $wpdb->insert_id;
			}
		}

		if($tot_imported>0){
			$log_title = "Import Account Successfully";
			$details = "Total Account Imported:{$tot_imported}";
			$status = 1;
		}else{
			$log_title = "Import Account Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No Account Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";
			$status = 0;
		}
		$this->save_log(array('log_type'=>'Account','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}

	/*Class Import Request/Response*/
	public function Class_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<ClassQueryRq requestID="' . $requestID . '">
					</ClassQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}

	public function Class_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);

		global $wpdb;

		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/ClassQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_list_class';

			/*Delete Old Data*/
			$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
			$wpdb->query("TRUNCATE TABLE {$table}");

			foreach ($List->children() as $Class){
				$tot_imported++;
				$arr = array(
				'ListID' => $Class->getChildDataAt('ClassRet ListID'),
				'Name' => $Class->getChildDataAt('ClassRet Name'),
				'IsActive' => $Class->getChildDataAt('ClassRet IsActive'),
				'Sublevel' => $Class->getChildDataAt('ClassRet Sublevel'),

				'Parent_ListID' => $Class->getChildDataAt('ClassRet ParentRef ListID'),
				'Parent_FullName' => $Class->getChildDataAt('ClassRet ParentRef FullName'),

				);

				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_id'] = $arr['ListID'];
				$save_data['name'] = $arr['Name'];
				$save_data['is_active'] = ($arr['IsActive']=='true')?1:0;

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = serialize($Class);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				$wpdb->insert($table, $save_data);
				//$lastid = $wpdb->insert_id;

			}
		}

		if($tot_imported>0){
			$log_title = "Import Class Successfully";
			$details = "Total Class Imported:{$tot_imported}";
			$status = 1;
		}else{
			$log_title = "Import Class Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No Class Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";
			$status = 0;
		}
		$this->save_log(array('log_type'=>'Class','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}

	/*SalesTaxCode Import Request/Response*/
	public function SalesTaxCode_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<SalesTaxCodeQueryRq requestID="' . $requestID . '">
					</SalesTaxCodeQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}

	public function SalesTaxCode_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);

		global $wpdb;

		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/SalesTaxCodeQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_list_salestaxcode';

			/*Delete Old Data*/
			$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
			$wpdb->query("TRUNCATE TABLE {$table}");

			foreach ($List->children() as $SalesTaxCode){
				$tot_imported++;
				$arr = array(
				'ListID' => $SalesTaxCode->getChildDataAt('SalesTaxCodeRet ListID'),
				'Name' => $SalesTaxCode->getChildDataAt('SalesTaxCodeRet Name'),
				'IsActive' => $SalesTaxCode->getChildDataAt('SalesTaxCodeRet IsActive'),
				'Desc' => $SalesTaxCode->getChildDataAt('SalesTaxCodeRet Desc'),
				'IsTaxable' => $SalesTaxCode->getChildDataAt('SalesTaxCodeRet IsTaxable'),
				);

				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_id'] = $arr['ListID'];
				$save_data['name'] = $arr['Name'];
				$save_data['stc_desc'] = $arr['Desc'];
				$save_data['is_active'] = ($arr['IsActive']=='true')?1:0;
				$save_data['is_taxable'] = ($arr['IsTaxable']=='true')?1:0;

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = serialize($SalesTaxCode);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				$wpdb->insert($table, $save_data);
				//$lastid = $wpdb->insert_id;

			}
		}

		if($tot_imported>0){
			$log_title = "Import SalesTaxCode Successfully";
			$details = "Total SalesTaxCode Imported:{$tot_imported}";
			$status = 1;
		}else{
			$log_title = "Import SalesTaxCode Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No SalesTaxCode Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";
			$status = 0;
		}
		$this->save_log(array('log_type'=>'SalesTaxCode','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}

	/*Terms Import Request/Response*/
	public function Terms_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<TermsQueryRq requestID="' . $requestID . '">
					</TermsQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}

	public function Terms_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);
		//return;
		global $wpdb;

		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){

			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/TermsQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_list_term';

			/*Delete Old Data*/
			$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
			$wpdb->query("TRUNCATE TABLE {$table}");

			foreach ($List->children() as $Term){
				$tot_imported++;
				$type = substr($Term->name(), 0, -8);
				$ret = $Term->name();

				$arr = array(
				'ListID' => $Term->getChildDataAt($ret.' ListID'),
				'Name' => $Term->getChildDataAt($ret.' Name'),
				'Type' => $type,
				'IsActive' => $Term->getChildDataAt($ret.' IsActive'),
				'Desc' => $Term->getChildDataAt($ret.' Desc'),
				'IsTaxable' => $Term->getChildDataAt($ret.' IsTaxable'),
				);

				if($type=='Standard'){
					$arr['StdDueDays'] = $Term->getChildDataAt($ret.' StdDueDays');
					$arr['StdDiscountDays'] = $Term->getChildDataAt($ret.' StdDiscountDays');
					$arr['DiscountPct'] = $Term->getChildDataAt($ret.' DiscountPct');
				}

				if($type=='DateDriven'){
					$arr['DayOfMonthDue'] = $Term->getChildDataAt($ret.' DayOfMonthDue');
					$arr['DueNextMonthDays'] = $Term->getChildDataAt($ret.' DueNextMonthDays');
					$arr['DiscountDayOfMonth'] = $Term->getChildDataAt($ret.' DiscountDayOfMonth');
					$arr['DiscountPct'] = $Term->getChildDataAt($ret.' DiscountPct');
				}

				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_id'] = $arr['ListID'];
				$save_data['name'] = $arr['Name'];
				$save_data['is_active'] = ($arr['IsActive']=='true')?1:0;
				$save_data['t_type'] = $arr['Type'];

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = serialize($Term);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				$wpdb->insert($table, $save_data);
				//$lastid = $wpdb->insert_id;

			}
		}

		if($tot_imported>0){
			$log_title = "Import Terms Successfully";
			$details = "Total Terms Imported:{$tot_imported}";
			$status = 1;
		}else{
			$log_title = "Import Terms Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No Terms Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";

			$status = 0;
		}
		$this->save_log(array('log_type'=>'Terms','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}
	
	/*InventorySite Import Request/Response*/
	public function InventorySite_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<InventorySiteQueryRq requestID="' . $requestID . '">
					</InventorySiteQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}
	
	public function InventorySite_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);
		//return;
		global $wpdb;

		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){

			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/InventorySiteQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_list_inventorysite';

			/*Delete Old Data*/
			$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
			$wpdb->query("TRUNCATE TABLE {$table}");

			foreach ($List->children() as $InventorySite){
				$tot_imported++;				
				$ret = $InventorySite->name();

				$arr = array(
				'ListID' => $InventorySite->getChildDataAt($ret.' ListID'),
				'Name' => $InventorySite->getChildDataAt($ret.' Name'),				
				'IsActive' => $InventorySite->getChildDataAt($ret.' IsActive'),
				'IsDefaultSite' => $InventorySite->getChildDataAt($ret.' IsDefaultSite'),
				'SiteDesc' => $InventorySite->getChildDataAt($ret.' SiteDesc'),
				
				'Contact' => $InventorySite->getChildDataAt($ret.' Contact'),
				'Phone' => $InventorySite->getChildDataAt($ret.' Phone'),
				'Fax' => $InventorySite->getChildDataAt($ret.' Fax'),
				'Email' => $InventorySite->getChildDataAt($ret.' Email'),
				);
				
				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_id'] = $arr['ListID'];
				$save_data['name'] = $arr['Name'];
				$save_data['is_active'] = ($arr['IsActive']=='true')?1:0;
				$save_data['is_default'] = ($arr['IsDefaultSite']=='true')?1:0;
				$save_data['s_desc'] = $arr['SiteDesc'];

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = serialize($Term);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				$wpdb->insert($table, $save_data);
				//$lastid = $wpdb->insert_id;

			}
		}
		
		if($tot_imported>0){
			$log_title = "Import InventorySite Successfully";
			$details = "Total InventorySite Imported:{$tot_imported}";
			$status = 1;
		}else{
			$log_title = "Import InventorySite Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No InventorySite Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";

			$status = 0;
		}
		$this->save_log(array('log_type'=>'InventorySite','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}
	
	/*OtherName Import Request/Response*/
	public function OtherName_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<OtherNameQueryRq requestID="' . $requestID . '">
					</OtherNameQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}
	
	public function OtherName_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);
		//return;
		global $wpdb;

		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){

			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/OtherNameQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_list_othername';

			/*Delete Old Data*/
			$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
			$wpdb->query("TRUNCATE TABLE {$table}");

			foreach ($List->children() as $OtherName){
				$tot_imported++;				
				$ret = $OtherName->name();

				$arr = array(
				'ListID' => $OtherName->getChildDataAt($ret.' ListID'),
				'Name' => $OtherName->getChildDataAt($ret.' Name'),				
				'IsActive' => $OtherName->getChildDataAt($ret.' IsActive'),				
				'CompanyName' => $OtherName->getChildDataAt($ret.' CompanyName'),
				
				'Salutation' => $OtherName->getChildDataAt($ret.' Salutation'),
				'FirstName' => $OtherName->getChildDataAt($ret.' FirstName'),
				'MiddleName' => $OtherName->getChildDataAt($ret.' MiddleName'),
				'LastName' => $OtherName->getChildDataAt($ret.' LastName'),
				);
				
				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_id'] = $arr['ListID'];
				$save_data['name'] = $arr['Name'];
				$save_data['is_active'] = ($arr['IsActive']=='true')?1:0;				
				$save_data['companyname'] = $arr['CompanyName'];

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = serialize($Term);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				$wpdb->insert($table, $save_data);
				//$lastid = $wpdb->insert_id;

			}
		}
		
		if($tot_imported>0){
			$log_title = "Import OtherName Successfully";
			$details = "Total OtherName Imported:{$tot_imported}";
			$status = 1;
		}else{
			$log_title = "Import OtherName Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No OtherName Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";

			$status = 0;
		}
		$this->save_log(array('log_type'=>'OtherName','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}
	
	/*SalesRep Import Request/Response*/
	public function SalesRep_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<SalesRepQueryRq requestID="' . $requestID . '">
					</SalesRepQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}
	
	public function SalesRep_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);
		//return;
		global $wpdb;
		
		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){

			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/SalesRepQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_list_salesrep';

			/*Delete Old Data*/
			$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
			$wpdb->query("TRUNCATE TABLE {$table}");

			foreach ($List->children() as $SalesRep){
				$tot_imported++;				
				$ret = $SalesRep->name();

				$arr = array(
				'ListID' => $SalesRep->getChildDataAt($ret.' ListID'),				
				'IsActive' => $SalesRep->getChildDataAt($ret.' IsActive'),				
				
				'SalesRepEntityRef_ListID' => $SalesRep->getChildDataAt($ret.' SalesRepEntityRef ListID'),
				'SalesRepEntityRef_FullName' => $SalesRep->getChildDataAt($ret.' SalesRepEntityRef FullName'),
				'Initial' => $SalesRep->getChildDataAt($ret.' Initial'),				
				);
				
				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_id'] = $arr['ListID'];
				
				$save_data['is_active'] = ($arr['IsActive']=='true')?1:0;				
				$save_data['sr_e_ref_id'] = $arr['SalesRepEntityRef_ListID'];
				$save_data['sr_e_ref_name'] = $arr['SalesRepEntityRef_FullName'];

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = serialize($Term);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				if(!empty($save_data['sr_e_ref_id'])){
					$wpdb->insert($table, $save_data);
				}
				
				//$lastid = $wpdb->insert_id;

			}
		}
		
		if($tot_imported>0){
			$log_title = "Import SalesRep Successfully";
			$details = "Total SalesRep Imported:{$tot_imported}";
			$status = 1;
		}else{
			$log_title = "Import SalesRep Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No SalesRep Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";

			$status = 0;
		}
		$this->save_log(array('log_type'=>'SalesRep','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}
	
	
	/*CustomerType Import Request/Response*/
	public function CustomerType_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<CustomerTypeQueryRq requestID="' . $requestID . '">
					</CustomerTypeQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}
	
	public function CustomerType_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}

		//$this->add_test_log($xml);
		//return;
		global $wpdb;

		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		$tot_imported = 0;
		if ($Doc = $Parser->parse($errnum, $errmsg)){

			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/CustomerTypeQueryRs');

			$table = $wpdb->prefix.'mw_wc_qbo_desk_qbd_list_customertype';

			/*Delete Old Data*/
			$wpdb->query("DELETE FROM {$table} WHERE `id` > 0");
			$wpdb->query("TRUNCATE TABLE {$table}");

			foreach ($List->children() as $CustomerType){
				$tot_imported++;
				$type = substr($CustomerType->name(), 0, -8);
				$ret = $CustomerType->name();

				$arr = array(
				'ListID' => $CustomerType->getChildDataAt($ret.' ListID'),
				'Name' => $CustomerType->getChildDataAt($ret.' Name'),				
				'IsActive' => $CustomerType->getChildDataAt($ret.' IsActive'),				
				'FullName' => $CustomerType->getChildDataAt($ret.' FullName'),
				
				'Sublevel' => $CustomerType->getChildDataAt($ret.' Sublevel'),				
				);
				
				//$this->add_test_log(print_r($arr,true));

				$save_data = array();
				$save_data['qbd_id'] = $arr['ListID'];
				$save_data['name'] = $arr['Name'];
				$save_data['is_active'] = ($arr['IsActive']=='true')?1:0;				

				$save_data['info_arr'] = serialize($arr);
				//$save_data['info_qbxml_obj'] = serialize($Term);
				//$save_data['info_qbxml_obj'] = $xml;
				$save_data['info_qbxml_obj'] = '';
				$wpdb->insert($table, $save_data);
				//$lastid = $wpdb->insert_id;

			}
		}
		
		if($tot_imported>0){
			$log_title = "Import CustomerType Successfully";
			$details = "Total CustomerType Imported:{$tot_imported}";
			$status = 1;
		}else{
			$log_title = "Import CustomerType Error";
			$errmsg = (!empty($errmsg))?$errmsg:"No CustomerType Found";
			$details = ($errnum)?"Error Number:{$errnum}\n"."Error:{$errmsg}":"Error:{$errmsg}";

			$status = 0;
		}
		$this->save_log(array('log_type'=>'CustomerType','log_title'=>$log_title,'details'=>$details,'status'=>$status),true);

		return true;
	}
	
	/*Preferences Import Request/Response*/
	public function Preferences_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<PreferencesQueryRq requestID="' . $requestID . '">
					</PreferencesQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}

	public function Preferences_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		//$this->add_test_log($xml);


		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/PreferencesQueryRs');
			foreach ($List->children() as $Preferences){
				$ret = $Preferences->name();
				$arr = array();
				$arr['IsMultiCurrencyOn'] = $Preferences->getChildDataAt($ret.' MultiCurrencyPreferences IsMultiCurrencyOn');
				$arr['PaySalesTax'] = $Preferences->getChildDataAt($ret.' SalesTaxPreferences PaySalesTax');
				$arr['added_date'] = $this->get_cdt();
				//$this->add_test_log(print_r($arr,true));
				update_option('mw_wc_qbo_desk_qbd_preferences_arr',$arr);
				update_option('mw_wc_qbo_desk_qbd_preferences_qbxml',$xml);
				$this->save_log(array('log_type'=>'Preferences','log_title'=>'Import Preferences','details'=>'Preferences Imported Successfully','status'=>1),true);

			}
		}

	}

	/*Company Import Request/Response*/
	public function Company_Import_Request($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $version, $locale){
		if(!$this->is_qwc_connected()){
			return false;
		}

		// Build the request
		$xml = '<?xml version="1.0" encoding="utf-8"?>
			<?qbxml version="' . $version . '"?>
			<QBXML>
				<QBXMLMsgsRq onError="'.$this->getonError().'">
					<CompanyQueryRq requestID="' . $requestID . '">
					</CompanyQueryRq>
				</QBXMLMsgsRq>
			</QBXML>';

		//$this->add_test_log($xml);
		return $xml;

	}

	public function Company_Import_Response($requestID, $user, $action, $ID, $extra, &$err, $last_action_time, $last_actionident_time, $xml, $idents){
		if(!$this->is_qwc_connected()){
			return false;
		}
		//$this->add_test_log($xml);


		$errnum = 0;
		$errmsg = '';
		$Parser = new QuickBooks_XML_Parser($xml);

		if ($Doc = $Parser->parse($errnum, $errmsg)){
			$Root = $Doc->getRoot();
			$List = $Root->getChildAt('QBXML/QBXMLMsgsRs/CompanyQueryRs');
			foreach ($List->children() as $Company){
				$ret = $Company->name();
				$arr = array();
				$arr['CompanyName'] = $Company->getChildDataAt($ret.' CompanyName');
				$arr['Email'] = $Company->getChildDataAt($ret.' Email');
				$arr['Country'] = $Company->getChildDataAt($ret.' Address Country');
				$arr['added_date'] = $this->get_cdt();
				//$this->add_test_log(print_r($arr,true));
				update_option('mw_wc_qbo_desk_qbd_company_info_arr',$arr);
				update_option('mw_wc_qbo_desk_qbd_company_info_qbxml',$xml);
				$this->save_log(array('log_type'=>'Company','log_title'=>'Import Company','details'=>'Company info Imported Successfully','status'=>1),true);
			}
		}

	}

	/*Import Functions End*/

	public function _quickbooks_get_last_run($user, $action){
		$type = null;
		$opts = null;
		return QuickBooks_Utilities::configRead($this->dsn, $user, md5(__FILE__), QB_QUICKBOOKS_CONFIG_LAST . '-' . $action, $type, $opts);
	}

	public function _quickbooks_set_last_run($user, $action, $force = null){
		$value = date('Y-m-d') . 'T' . date('H:i:s');
		if ($force){
			$value = date('Y-m-d', strtotime($force)) . 'T' . date('H:i:s', strtotime($force));
		}
		return QuickBooks_Utilities::configWrite($this->dsn, $user, md5(__FILE__), QB_QUICKBOOKS_CONFIG_LAST . '-' . $action, $value);
	}

	public function _quickbooks_get_current_run($user, $action){
		$type = null;
		$opts = null;
		return QuickBooks_Utilities::configRead($this->dsn, $user, md5(__FILE__), QB_QUICKBOOKS_CONFIG_CURR . '-' . $action, $type, $opts);
	}

	public function _quickbooks_set_current_run($user, $action, $force = null){
		$value = date('Y-m-d') . 'T' . date('H:i:s');

		if ($force){
			$value = date('Y-m-d', strtotime($force)) . 'T' . date('H:i:s', strtotime($force));
		}

		return QuickBooks_Utilities::configWrite($this->dsn, $user, md5(__FILE__), QB_QUICKBOOKS_CONFIG_CURR . '-' . $action, $value);
	}
}
